''' Datasets used in [2]. Shows the tuple of 1-tuples structure needed by Anew.

small_artifical, phagemid and iGEM_2008 reproduced from [1].

@author: Jonathan Blakes <jonathan.blakes@nottingham.ac.uk>
@copyright (c) 2013-present Jonathan Blakes
@date August 31th 2013
@license: LGPLv3, http://www.gnu.org/licenses/lgpl-3.0.txt

References:

[1]	Densmore, D., Hsiau, T. H.-C., Kittleson, J. T., DeLoache, W., Batten, C. 
	and Anderson, J. C. 2010. Algorithms for automated DNA assembly. 
	Nucleic Acids Research 38, 8 (Mar. 2010), 2607-2616. 
	DOI=http://dx.doi.org/10.1093/nar/gkq165

[2]	Blakes, J., Raz, O., Feige, U., Bacardit, J. Ben-Yehezkel, T., Shapiro, E. 
	and Krasnogor, N. A heuristic for maximizing DNA reuse in synthetic 
	DNA library assembly. ACS Synthetic Biology (submitted 2013).

'''


# useful functions

def remove_duplicates_retaining_order(hashables):
	# use OrderedDict like ordered set 
	from collections import OrderedDict
	oset = OrderedDict()
	for hashable in hashables:
		oset[hashable] = None
	return oset.keys()

# used here by phagemid and iGEM_2008 
def hashable(seq):
	return tuple(map(tuple, [(part,) for part in seq]))


# libraries from [1] Supplementary Material

def small_artificial():
	'''	"exhaustive" '''
	return [
(('g',),('m',),('o',),('c',),),
(('o',),('p',),('m',),('o',),('c',),),
(('q',),('b',),('m',),('o',),('c',),),
(('a',),('d',),('m',),('o',),('c',),),
(('z',),('y',),('m',),('o',),('c',),),
	]

def phagemid():
	phagemid = '''
Promoter1.ORF1.ORF3.Term1.Promoter2.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF1.Term1.Promoter2.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF2.Term1.Promoter2.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF3.Term1.Promoter2.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF4.Term1.Promoter2.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF1.ORF3.Term1.Promoter3.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF1.Term1.Promoter3.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF2.Term1.Promoter3.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF3.Term1.Promoter3.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF4.Term1.Promoter3.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF1.ORF3.Term1.Promoter2.ORF5.Term2.ORF7.Term3
Promoter1.ORF1.Term1.Promoter2.ORF5.Term2.ORF7.Term3
Promoter1.ORF2.Term1.Promoter2.ORF5.Term2.ORF7.Term3
Promoter1.ORF3.Term1.Promoter2.ORF5.Term2.ORF7.Term3
Promoter1.ORF4.Term1.Promoter2.ORF5.Term2.ORF7.Term3
Promoter1.ORF1.ORF3.Term1.Promoter3.ORF5.Term2.ORF7.Term3
Promoter1.ORF1.Term1.Promoter3.ORF5.Term2.ORF7.Term3
Promoter1.ORF2.Term1.Promoter3.ORF5.Term2.ORF7.Term3
Promoter1.ORF3.Term1.Promoter3.ORF5.Term2.ORF7.Term3
Promoter1.ORF4.Term1.Promoter3.ORF5.Term2.ORF7.Term3
Promoter4.ORF6.Term3.Promoter2.ORF5.Term2.Promoter1.ORF1.ORF3.Term1
Promoter4.ORF6.Term3.Promoter2.ORF5.Term2.Promoter1.ORF1.Term1
Promoter4.ORF6.Term3.Promoter2.ORF5.Term2.Promoter1.ORF2.Term1
Promoter4.ORF6.Term3.Promoter2.ORF5.Term2.Promoter1.ORF3.Term1
Promoter4.ORF6.Term3.Promoter2.ORF5.Term2.Promoter1.ORF4.Term1
Promoter4.ORF6.Term3.Promoter3.ORF5.Term2.Promoter1.ORF1.ORF3.Term1
Promoter4.ORF6.Term3.Promoter3.ORF5.Term2.Promoter1.ORF1.Term1
Promoter4.ORF6.Term3.Promoter3.ORF5.Term2.Promoter1.ORF2.Term1
Promoter4.ORF6.Term3.Promoter3.ORF5.Term2.Promoter1.ORF3.Term1
Promoter4.ORF6.Term3.Promoter3.ORF5.Term2.Promoter1.ORF4.Term1
ORF7.Term3.Promoter2.ORF5.Term2.Promoter1.ORF1.ORF3.Term1
ORF7.Term3.Promoter2.ORF5.Term2.Promoter1.ORF1.Term1
ORF7.Term3.Promoter2.ORF5.Term2.Promoter1.ORF2.Term1
ORF7.Term3.Promoter2.ORF5.Term2.Promoter1.ORF3.Term1
ORF7.Term3.Promoter2.ORF5.Term2.Promoter1.ORF4.Term1
ORF7.Term3.Promoter3.ORF5.Term2.Promoter1.ORF1.ORF3.Term1
ORF7.Term3.Promoter3.ORF5.Term2.Promoter1.ORF1.Term1
ORF7.Term3.Promoter3.ORF5.Term2.Promoter1.ORF2.Term1
ORF7.Term3.Promoter3.ORF5.Term2.Promoter1.ORF3.Term1
ORF7.Term3.Promoter3.ORF5.Term2.Promoter1.ORF4.Term1
Promoter1.ORF1.ORF3.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF1.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF2.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF3.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF4.ORF5.Term2.Promoter4.ORF6.Term3
Promoter1.ORF1.ORF3.ORF5.Term2.ORF7.Term3
Promoter1.ORF1.ORF5.Term2.ORF7.Term3
Promoter1.ORF2.ORF5.Term2.ORF7.Term3
Promoter1.ORF3.ORF5.Term2.ORF7.Term3
Promoter1.ORF4.ORF5.Term2.ORF7.Term3
Promoter2.ORF5.Term2.Promoter1.ORF1.ORF3.ORF6.Term3
Promoter2.ORF5.Term2.Promoter1.ORF1.ORF6.Term3
Promoter2.ORF5.Term2.Promoter1.ORF2.ORF6.Term3
Promoter2.ORF5.Term2.Promoter1.ORF3.ORF6.Term3
Promoter2.ORF5.Term2.Promoter1.ORF4.ORF6.Term3
Promoter3.ORF5.Term2.Promoter1.ORF1.ORF3.ORF6.Term3
Promoter3.ORF5.Term2.Promoter1.ORF1.ORF6.Term3
Promoter3.ORF5.Term2.Promoter1.ORF2.ORF6.Term3
Promoter3.ORF5.Term2.Promoter1.ORF3.ORF6.Term3
Promoter3.ORF5.Term2.Promoter1.ORF4.ORF6.Term3
Promoter1.ORF1.ORF3.Promoter3.ORF5.ORF6.Term3
Promoter1.ORF1.Promoter3.ORF5.ORF6.Term3
Promoter1.ORF2.Promoter3.ORF5.ORF6.Term3
Promoter1.ORF3.Promoter3.ORF5.ORF6.Term3
Promoter1.ORF4.Promoter3.ORF5.ORF6.Term3
Promoter1.ORF1.ORF3.Promoter2.ORF5.ORF6.Term3
Promoter1.ORF1.Promoter2.ORF5.ORF6.Term3
Promoter1.ORF2.Promoter2.ORF5.ORF6.Term3
Promoter1.ORF3.Promoter2.ORF5.ORF6.Term3
Promoter1.ORF4.Promoter2.ORF5.ORF6.Term3
Promoter1.ORF1.ORF3.Term1.Prom-ORF1.Term2.ORF6.Term3
Promoter1.ORF1.Term1.Prom-ORF1.Term2.ORF6.Term3
Promoter1.ORF2.Term1.Prom-ORF1.Term2.ORF6.Term3
Promoter1.ORF3.Term1.Prom-ORF1.Term2.ORF6.Term3
Promoter1.ORF4.Term1.Prom-ORF1.Term2.ORF6.Term3
Promoter1.ORF1.ORF3.Term1.Prom-ORF2.Term2.ORF6.Term3
Promoter1.ORF1.Term1.Prom-ORF2.Term2.ORF6.Term3
Promoter1.ORF2.Term1.Prom-ORF2.Term2.ORF6.Term3
Promoter1.ORF3.Term1.Prom-ORF2.Term2.ORF6.Term3
Promoter1.ORF4.Term1.Prom-ORF2.Term2.ORF6.Term3
ORF6.Term3.Prom-ORF1.Term2.Promoter1.ORF1.ORF3.Term1
ORF6.Term3.Prom-ORF1.Term2.Promoter1.ORF1.Term1
ORF6.Term3.Prom-ORF1.Term2.Promoter1.ORF2.Term1
ORF6.Term3.Prom-ORF1.Term2.Promoter1.ORF3.Term1
ORF6.Term3.Prom-ORF1.Term2.Promoter1.ORF4.Term1
ORF6.Term3.Prom-ORF2.Term2.Promoter1.ORF1.ORF3.Term1
ORF6.Term3.Prom-ORF2.Term2.Promoter1.ORF1.Term1
ORF6.Term3.Prom-ORF2.Term2.Promoter1.ORF2.Term1
ORF6.Term3.Prom-ORF2.Term2.Promoter1.ORF3.Term1
ORF6.Term3.Prom-ORF2.Term2.Promoter1.ORF4.Term1
Promoter1.ORF1.ORF3.ORF5.Term2.ORF6.Term3
Promoter1.ORF1.ORF5.Term2.ORF6.Term3
Promoter1.ORF2.ORF5.Term2.ORF6.Term3
Promoter1.ORF3.ORF5.Term2.ORF6.Term3
Promoter1.ORF4.ORF5.Term2.ORF6.Term3
Prom-ORF1.Term2.Promoter1.ORF1.ORF3.ORF7.Term3
Prom-ORF1.Term2.Promoter1.ORF1.ORF7.Term3
Prom-ORF1.Term2.Promoter1.ORF2.ORF7.Term3
Prom-ORF1.Term2.Promoter1.ORF3.ORF7.Term3
Prom-ORF1.Term2.Promoter1.ORF4.ORF7.Term3
Prom-ORF2.Term2.Promoter1.ORF1.ORF3.ORF7.Term3
Prom-ORF2.Term2.Promoter1.ORF1.ORF7.Term3
Prom-ORF2.Term2.Promoter1.ORF2.ORF7.Term3
Prom-ORF2.Term2.Promoter1.ORF3.ORF7.Term3
Prom-ORF2.Term2.Promoter1.ORF4.ORF7.Term3
Promoter1.ORF1.ORF3.Prom-ORF1.ORF7.Term3
Promoter1.ORF1.Prom-ORF1.ORF7.Term3
Promoter1.ORF2.Prom-ORF1.ORF7.Term3
Promoter1.ORF3.Prom-ORF1.ORF7.Term3
Promoter1.ORF4.Prom-ORF1.ORF7.Term3
Promoter1.ORF1.ORF3.Prom-ORF2.ORF7.Term3
Promoter1.ORF1.Prom-ORF2.ORF7.Term3
Promoter1.ORF2.Prom-ORF2.ORF7.Term3
Promoter1.ORF3.Prom-ORF2.ORF7.Term3
Promoter1.ORF4.Prom-ORF2.ORF7.Term3
Prom-ORF1.Term1.Promoter1.ORF1.ORF3.ORF5.Term2
Prom-ORF1.Term1.Promoter1.ORF1.ORF5.Term2
Prom-ORF1.Term1.Promoter1.ORF2.ORF5.Term2
Prom-ORF1.Term1.Promoter1.ORF4.ORF5.Term2
Prom-ORF2.Term1.Promoter1.ORF1.ORF3.ORF5.Term2
Prom-ORF2.Term1.Promoter1.ORF1.ORF5.Term2
Prom-ORF2.Term1.Promoter1.ORF2.ORF5.Term2
Prom-ORF2.Term1.Promoter1.ORF4.ORF5.Term2
Promoter1.ORF1.ORF3.Prom-ORF1.ORF5.Term2
Promoter1.ORF1.Prom-ORF1.ORF5.Term2
Promoter1.ORF2.Prom-ORF1.ORF5.Term2
Promoter1.ORF4.Prom-ORF1.ORF5.Term2
Promoter1.ORF1.ORF3.Prom-ORF2.ORF5.Term2
Promoter1.ORF1.Prom-ORF2.ORF5.Term2
Promoter1.ORF2.Prom-ORF2.ORF5.Term2
Promoter1.ORF4.Prom-ORF2.ORF5.Term2
	'''
	return map(hashable, [s.split('.') for s in phagemid.strip().split('\n')])

def iGEM_2008():
	''' Contains three instances of {Pbad.rbs1-A} so 395 sequences not 397 
	(after duplicates removed by remove_duplicates_retaining_order) '''
	iGEM_2008 = '''
{Pbad}.{rbs1-A}.{fimH>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}
{pelB>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{ompT>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{ATG}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}
{phoApp>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}
{lamB>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~pelB>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~ompT>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~phoApp>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~lamB>}.{<phoA!}.{b1006}
{Pbad}.{rbs_pelB>}.{<phoA!}.{b1006}
{Pbad}.{rbs_ompT>}.{<phoA!}.{b1006}
{Pbad}.{rbs_phoApp>}.{<phoA!}.{b1006}
{Pbad}.{rbs_lamB>}.{<phoA!}.{b1006}
{Pspv}.{rbs1-A}
{Pdps}.{rbs1-A}
{PbolA}.{rbs1-A}
{PftsQ}.{rbs1-A}
{PftsAZ}.{rbs1-A}
{Phns}.{rbs1-A}
{PrrnB_P1}.{rbs1-A}
{PfhuA}.{rbs1-A}
{Ptet}.{rbs1-A}
{PbolA}.{rbs_spvR!}.{Pspv2}.{rbs1-A}
{PftsQ}.{rbs_spvR!}.{Pspv2}.{rbs1-A}
{PftsAZ}.{rbs_spvR!}.{Pspv2}.{rbs1-A}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbs1-A}
{PfhuA}.{rbs_spvR!}.{Pspv2}.{rbs1-A}
{Ptet}.{rbs_spvR!}.{Pspv2}.{rbs1-A}
{Pbad}.{rbs_spvR!}.{Pspv2}.{rbs1-A}
{Pbad}.{rbs1-A}.{ompT>}.{<int>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{ompT>}.{<barnase>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{ompT>}.{<cre>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{ompT>}.{<cre>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{ompT>}.{<barnase>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{ompT>}.{<int>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{pelB>}.{<xis>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{pelB>}.{<ligase>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{pelB>}.{<ligase>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{pelB>}.{<xis>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{lamB>}.{<BglII>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{lamB>}.{<ihfA>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{lamB>}.{<BglII>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{lamB>}.{<ihfA>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{phoApp>}.{<BamHI>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{phoApp>}.{<BamHI>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{phoApp>}.{<ihfB>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{phoApp>}.{<ihfB>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~ompT>}.{<int>}.{<phoA!}.{b1006}
{Pbad}.{rbs_ompT>}.{<int>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~pelB>}.{<xis>}.{<phoA!}.{b1006}
{Pbad}.{rbs_pelB>}.{<xis>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~ompT>}.{<barnase>}.{<phoA!}.{b1006}
{Pbad}.{rbs_ompT>}.{<barnase>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~ompT>}.{<cre>}.{<phoA!}.{b1006}
{Pbad}.{rbs_ompT>}.{<cre>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~pelB>}.{<ligase>}.{<phoA!}.{b1006}
{Pbad}.{rbs_pelB>}.{<ligase>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~phoApp>}.{<BamHI>}.{<phoA!}.{b1006}
{Pbad}.{rbs_phoApp>}.{<BamHI>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~lamB>}.{<BglII>}.{<phoA!}.{b1006}
{Pbad}.{rbs_lamB>}.{<BglII>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~lamB>}.{<ihfA>}.{<phoA!}.{b1006}
{Pbad}.{rbs_lamB>}.{<ihfA>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~phoApp>}.{<ihfB>}.{<phoA!}.{b1006}
{Pbad}.{rbs_phoApp>}.{<ihfB>}.{<phoA!}.{b1006}
{Pbad}.{rbsa~}.{a~ompT>}.{<cre>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_ompT>}.{<cre>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~ompT>}.{<barnase>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_ompT>}.{<barnase>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~pelB>}.{<ligase>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_pelB>}.{<ligase>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~phoApp>}.{<BamHI>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_phoApp>}.{<BamHI>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~lamB>}.{<BglII>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_lamB>}.{<BglII>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~ompT>}.{<int>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_ompT>}.{<int>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~pelB>}.{<xis>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_pelB>}.{<xis>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~lamB>}.{<ihfA>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_lamB>}.{<ihfA>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~phoApp>}.{<ihfB>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_phoApp>}.{<ihfB>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{cre>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~cre>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_cre>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{ligase>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~ligase>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_ligase>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{BamHI>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~BamHI>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_BamHI>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{BglII>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~BglII>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_BglII>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{xis>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~xis>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_xis>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{int>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~int>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_int>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{ihfA>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~ihfA>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_ihfA>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{ihfB>}.{<S-tag!}.{b1006}
{Pbad}.{rbsa~}.{a~ihfB>}.{<S-tag!}.{b1006}
{Pbad}.{rbs_ihfB>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{ATG}.{<barnase>}.{<S-tag!}
{Pbad}.{rbs_barstar>}.{<S-tag!}.{b1006}
{Pbad}.{rbs1-A}.{fimH>}.{<AP>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{fimH>}.{<HA>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{fimH>}.{<myc>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{fimH>}.{<FLAG>}.{<phoA!}.{b1006}
{Pbad}.{rbs1-A}.{fimH>}.{<phoA>}.{<AP!}.{b1006}
{Pbad}.{rbs1-A}.{fimH>}.{<phoA>}.{<HA!}.{b1006}
{Pbad}.{rbs1-A}.{fimH>}.{<phoA>}.{<myc!}.{b1006}
{Pbad}.{rbs1-A}.{fimH>}.{<phoA>}.{<FLAG!}.{b1006}
{Psound}.{rbs1-A}.{ompT>}.{<barnase!}.{rbs1-A}.{phoApp>}.{<BamHI!}.{rbs1-A}.{lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{Pbad}.{rbs1-A}.{ompT>}.{<barnase!}.{rbs1-A}.{phoApp>}.{<BamHI!}.{rbs1-A}.{lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{Pspv}.{rbs1-A}.{ompT>}.{<barnase!}.{rbs1-A}.{phoApp>}.{<BamHI!}.{rbs1-A}.{lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{PftsAZ}.{rbs1-A}.{ompT>}.{<barnase!}.{rbs1-A}.{phoApp>}.{<BamHI!}.{rbs1-A}.{lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{PftsQ}.{rbs1-A}.{ompT>}.{<barnase!}.{rbs1-A}.{phoApp>}.{<BamHI!}.{rbs1-A}.{lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{PbolA}.{rbs1-A}.{ompT>}.{<barnase!}.{rbs1-A}.{phoApp>}.{<BamHI!}.{rbs1-A}.{lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{Psound}.{rbsa~}.{a~ompT>}.{<barnase!}.{rbsa~}.{a~phoApp>}.{<BamHI!}.{rbsa~}.{a~lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{Pbad}.{rbsa~}.{a~ompT>}.{<barnase!}.{rbsa~}.{a~phoApp>}.{<BamHI!}.{rbsa~}.{a~lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{Pspv}.{rbsa~}.{a~ompT>}.{<barnase!}.{rbsa~}.{a~phoApp>}.{<BamHI!}.{rbsa~}.{a~lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{PftsAZ}.{rbsa~}.{a~ompT>}.{<barnase!}.{rbsa~}.{a~phoApp>}.{<BamHI!}.{rbsa~}.{a~lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{PftsQ}.{rbsa~}.{a~ompT>}.{<barnase!}.{rbsa~}.{a~phoApp>}.{<BamHI!}.{rbsa~}.{a~lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{PbolA}.{rbsa~}.{a~ompT>}.{<barnase!}.{rbsa~}.{a~phoApp>}.{<BamHI!}.{rbsa~}.{a~lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{Psound}.{rbs_ompT>}.{<barnase!}.{rbs_phoApp>}.{<BamHI!}.{rbs_lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{Pbad}.{rbs_ompT>}.{<barnase!}.{rbs_phoApp>}.{<BamHI!}.{rbs_lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{Pspv}.{rbs_ompT>}.{<barnase!}.{rbs_phoApp>}.{<BamHI!}.{rbs_lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{PftsAZ}.{rbs_ompT>}.{<barnase!}.{rbs_phoApp>}.{<BamHI!}.{rbs_lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{PftsQ}.{rbs_ompT>}.{<barnase!}.{rbs_phoApp>}.{<BamHI!}.{rbs_lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{PbolA}.{rbs_ompT>}.{<barnase!}.{rbs_phoApp>}.{<BamHI!}.{rbs_lamB>}.{<BglII!}.{b1006}.{Pcon-C5}.{rbs_barstar!}.{b0015}
{Psound}.{rbs1-A}.{int!}.{rbs1-A}.{xis!}.{rbs1-A}.{ihfA!}.{rbs1-A}.{ihfB!}.{b1006}
{Psound}.{rbsa~}.{a~int!}.{rbsa~}.{a~xis!}.{rbsa~}.{a~ihfA!}.{rbsa~}.{a~ihfB!}.{b1006}
{Psound}.{rbs_int!}.{rbs_xis!}.{rbs_ihfA!}.{rbs_ihfB!}.{b1006}
{Pbad}.{rbs1-A}.{int!}.{rbs1-A}.{xis!}.{rbs1-A}.{ihfA!}.{rbs1-A}.{ihfB!}.{b1006}
{Pbad}.{rbsa~}.{a~int!}.{rbsa~}.{a~xis!}.{rbsa~}.{a~ihfA!}.{rbsa~}.{a~ihfB!}.{b1006}
{Pbad}.{rbs_int!}.{rbs_xis!}.{rbs_ihfA!}.{rbs_ihfB!}.{b1006}
{Psound}.{rbs1-A}.{ompT>}.{<int!}.{rbs1-A}.{pelB>}.{<xis!}.{rbs1-A}.{lamB>}.{<ihfA!}.{rbs1-A}.{phoApp>}.{<ihfB!}.{b1006}
{Psound}.{rbsa~}.{a~ompT>}.{<int!}.{rbsa~}.{a~pelB>}.{<xis!}.{rbsa~}.{a~lamB>}.{<ihfA!}.{rbsa~}.{a~phoApp>}.{<ihfB!}.{b1006}
{Psound}.{rbs_ompT>}.{<int!}.{rbs_pelB>}.{<xis!}.{rbs_lamB>}.{<ihfA!}.{rbs_phoApp>}.{<ihfB!}.{b1006}
{Pbad}.{rbs1-A}.{ompT>}.{<int!}.{rbs1-A}.{pelB>}.{<xis!}.{rbs1-A}.{lamB>}.{<ihfA!}.{rbs1-A}.{phoApp>}.{<ihfB!}.{b1006}
{Pbad}.{rbsa~}.{a~ompT>}.{<int!}.{rbsa~}.{a~pelB>}.{<xis!}.{rbsa~}.{a~lamB>}.{<ihfA!}.{rbsa~}.{a~phoApp>}.{<ihfB!}.{b1006}
{Pbad}.{rbs_ompT>}.{<int!}.{rbs_pelB>}.{<xis!}.{rbs_lamB>}.{<ihfA!}.{rbs_phoApp>}.{<ihfB!}.{b1006}
{Psound}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon-B5}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Psound}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon-C5}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Psound}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon-G6}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Psound}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Psound}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon-J23100}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Psound}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon-B5}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Psound}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon-C5}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Psound}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon-G6}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Psound}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Psound}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon-J23100}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Psound}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon-B5}.{rbs_tantiholin!}.{Bca1041}
{Psound}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon-C5}.{rbs_tantiholin!}.{Bca1041}
{Psound}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon-G6}.{rbs_tantiholin!}.{Bca1041}
{Psound}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon}.{rbs_tantiholin!}.{Bca1041}
{Psound}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon-J23100}.{rbs_tantiholin!}.{Bca1041}
{Psound}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon-B5}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Psound}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon-C5}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Psound}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon-G6}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Psound}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Psound}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon-J23100}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Psound}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon-B5}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Psound}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon-C5}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Psound}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon-G6}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Psound}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Psound}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon-J23100}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Psound}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon-B5}.{rbs_lantiholin!}.{Bca1041}
{Psound}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon-C5}.{rbs_lantiholin!}.{Bca1041}
{Psound}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon-G6}.{rbs_lantiholin!}.{Bca1041}
{Psound}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon}.{rbs_lantiholin!}.{Bca1041}
{Psound}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon-J23100}.{rbs_lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon-B5}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon-C5}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon-G6}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon-J23100}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a_tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon-B5}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a_tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon-C5}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a_tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon-G6}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a_tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a_tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon-J23100}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon-B5}.{rbs_tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon-C5}.{rbs_tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon-G6}.{rbs_tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon}.{rbs_tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon-J23100}.{rbs_tantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon-B5}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon-C5}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon-G6}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon-J23100}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon-B5}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon-C5}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon-G6}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon-J23100}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon-B5}.{rbs_lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon-C5}.{rbs_lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon-G6}.{rbs_lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon}.{rbs_lantiholin!}.{Bca1041}
{Psound}.{rbs_spvR!}.{Pspv2}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon-J23100}.{rbs_lantiholin!}.{Bca1041}
{Pbad}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon-B5}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Pbad}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon-C5}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Pbad}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon-G6}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Pbad}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Pbad}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Pcon-J23100}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Pbad}.{rbsa~}.{a_tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon-B5}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Pbad}.{rbsa~}.{a_tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon-C5}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Pbad}.{rbsa~}.{a_tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon-G6}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Pbad}.{rbsa~}.{a_tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Pbad}.{rbsa~}.{a_tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Pcon-J23100}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Pbad}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon-B5}.{rbs_tantiholin!}.{Bca1041}
{Pbad}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon-C5}.{rbs_tantiholin!}.{Bca1041}
{Pbad}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon-G6}.{rbs_tantiholin!}.{Bca1041}
{Pbad}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon}.{rbs_tantiholin!}.{Bca1041}
{Pbad}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Pcon-J23100}.{rbs_tantiholin!}.{Bca1041}
{Pbad}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon-B5}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Pbad}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon-C5}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Pbad}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon-G6}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Pbad}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Pbad}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Pcon-J23100}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Pbad}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon-B5}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Pbad}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon-C5}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Pbad}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon-G6}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Pbad}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Pbad}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Pcon-J23100}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Pbad}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon-B5}.{rbs_lantiholin!}.{Bca1041}
{Pbad}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon-C5}.{rbs_lantiholin!}.{Bca1041}
{Pbad}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon-G6}.{rbs_lantiholin!}.{Bca1041}
{Pbad}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon}.{rbs_lantiholin!}.{Bca1041}
{Pbad}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Pcon-J23100}.{rbs_lantiholin!}.{Bca1041}
{Pspv}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Phns}.{rbs1-A}.{tantiholin!}.{Bca1041}
{PbolA}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Phns}.{rbs1-A}.{tantiholin!}.{Bca1041}
{PftsAZ}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Phns}.{rbs1-A}.{tantiholin!}.{Bca1041}
{PftsQ}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{Phns}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Pspv}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Phns}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{PbolA}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Phns}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{PftsAZ}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Phns}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{PftsQ}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{Phns}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Pspv}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Phns}.{rbs_tantiholin!}.{Bca1041}
{PbolA}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Phns}.{rbs_tantiholin!}.{Bca1041}
{PftsAZ}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Phns}.{rbs_tantiholin!}.{Bca1041}
{PftsQ}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{Phns}.{rbs_tantiholin!}.{Bca1041}
{Pspv}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{tantiholin!}.{Bca1041}
{PbolA}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{tantiholin!}.{Bca1041}
{PftsAZ}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{tantiholin!}.{Bca1041}
{PftsQ}.{rbs1-A}.{tLysozyme!}.{rbs1-A}.{tholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Pspv}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{PbolA}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{PftsAZ}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{PftsQ}.{rbsa~}.{a~tLysozyme!}.{rbsa~}.{a~tholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Pspv}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{PrrnB_P1}.{rbs_tantiholin!}.{Bca1041}
{PbolA}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{PrrnB_P1}.{rbs_tantiholin!}.{Bca1041}
{PftsAZ}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{PrrnB_P1}.{rbs_tantiholin!}.{Bca1041}
{PftsQ}.{rbs_tLysozyme!}.{rbs_tholin!}.{b0015}.{PrrnB_P1}.{rbs_tantiholin!}.{Bca1041}
{Pspv}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Phns}.{rbs1-A}.{lantiholin!}.{Bca1041}
{PbolA}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Phns}.{rbs1-A}.{lantiholin!}.{Bca1041}
{PftsAZ}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Phns}.{rbs1-A}.{lantiholin!}.{Bca1041}
{PftsQ}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{Phns}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Pspv}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Phns}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{PbolA}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Phns}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{PftsAZ}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Phns}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{PftsQ}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{Phns}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Pspv}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Phns}.{rbs_lantiholin!}.{Bca1041}
{PbolA}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Phns}.{rbs_lantiholin!}.{Bca1041}
{PftsAZ}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Phns}.{rbs_lantiholin!}.{Bca1041}
{PftsQ}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{Phns}.{rbs_lantiholin!}.{Bca1041}
{Pspv}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{lantiholin!}.{Bca1041}
{PbolA}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{lantiholin!}.{Bca1041}
{PftsAZ}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{lantiholin!}.{Bca1041}
{PftsQ}.{rbs1-A}.{lLysozyme!}.{rbs1-A}.{lholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Pspv}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{PbolA}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{PftsAZ}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{PftsQ}.{rbsa~}.{a~lLysozyme!}.{rbsa~}.{a~lholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Pspv}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{PrrnB_P1}.{rbs_lantiholin!}.{Bca1041}
{PbolA}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{PrrnB_P1}.{rbs_lantiholin!}.{Bca1041}
{PftsAZ}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{PrrnB_P1}.{rbs_lantiholin!}.{Bca1041}
{PftsQ}.{rbs_lLysozyme!}.{rbs_lholin!}.{b0015}.{PrrnB_P1}.{rbs_lantiholin!}.{Bca1041}
{PfhuA}.{rbs1-A}.{tLysozyme!}.{b1006}.{Pspv}.{rbs1-A}.{tholin!}.{b0015}.{Phns}.{rbs1-A}.{tantiholin!}.{Bca1041}
{PfhuA}.{rbsa~}.{a~tLysozyme!}.{b1006}.{Pspv}.{rbsa~}.{a~tholin!}.{b0015}.{Phns}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{PfhuA}.{rbs_tLysozyme!}.{b1006}.{Pspv}.{rbs_tholin!}.{b0015}.{Phns}.{rbs_tantiholin!}.{Bca1041}
{PfhuA}.{rbs1-A}.{tLysozyme!}.{b1006}.{Pspv}.{rbs1-A}.{tholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{tantiholin!}.{Bca1041}
{PfhuA}.{rbsa~}.{a~tLysozyme!}.{b1006}.{Pspv}.{rbsa~}.{a~tholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{PfhuA}.{rbs_tLysozyme!}.{b1006}.{Pspv}.{rbs_tholin!}.{b0015}.{PrrnB_P1}.{rbs_tantiholin!}.{Bca1041}
{PfhuA}.{rbs1-A}.{lLysozyme!}.{b1006}.{Pspv}.{rbs1-A}.{lholin!}.{b0015}.{Phns}.{rbs1-A}.{lantiholin!}.{Bca1041}
{PfhuA}.{rbsa~}.{a~lLysozyme!}.{b1006}.{Pspv}.{rbsa~}.{a~lholin!}.{b0015}.{Phns}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{PfhuA}.{rbs_lLysozyme!}.{b1006}.{Pspv}.{rbs_lholin!}.{b0015}.{Phns}.{rbs_lantiholin!}.{Bca1041}
{PfhuA}.{rbs1-A}.{lLysozyme!}.{b1006}.{Pspv}.{rbs1-A}.{lholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{lantiholin!}.{Bca1041}
{PfhuA}.{rbsa~}.{a~lLysozyme!}.{b1006}.{Pspv}.{rbsa~}.{a~lholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{PfhuA}.{rbs_lLysozyme!}.{b1006}.{Pspv}.{rbs_lholin!}.{b0015}.{PrrnB_P1}.{rbs_lantiholin!}.{Bca1041}
{Pspv}.{rbs1-A}.{tLysozyme!}.{b1006}.{PfhuA}.{rbs1-A}.{tholin!}.{b0015}.{Phns}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Pspv}.{rbsa~}.{a~tLysozyme!}.{b1006}.{PfhuA}.{rbsa~}.{a~tholin!}.{b0015}.{Phns}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Pspv}.{rbs_tLysozyme!}.{b1006}.{PfhuA}.{rbs_tholin!}.{b0015}.{Phns}.{rbs_tantiholin!}.{Bca1041}
{Pspv}.{rbs1-A}.{tLysozyme!}.{b1006}.{PfhuA}.{rbs1-A}.{tholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Pspv}.{rbsa~}.{a~tLysozyme!}.{b1006}.{PfhuA}.{rbsa~}.{a~tholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Pspv}.{rbs_tLysozyme!}.{b1006}.{PfhuA}.{rbs_tholin!}.{b0015}.{PrrnB_P1}.{rbs_tantiholin!}.{Bca1041}
{Pspv}.{rbs1-A}.{lLysozyme!}.{b1006}.{PfhuA}.{rbs1-A}.{lholin!}.{b0015}.{Phns}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Pspv}.{rbsa~}.{a~lLysozyme!}.{b1006}.{PfhuA}.{rbsa~}.{a~lholin!}.{b0015}.{Phns}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Pspv}.{rbs_lLysozyme!}.{b1006}.{PfhuA}.{rbs_lholin!}.{b0015}.{Phns}.{rbs_lantiholin!}.{Bca1041}
{Pspv}.{rbs1-A}.{lLysozyme!}.{b1006}.{PfhuA}.{rbs1-A}.{lholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Pspv}.{rbsa~}.{a~lLysozyme!}.{b1006}.{PfhuA}.{rbsa~}.{a~lholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Pspv}.{rbs_lLysozyme!}.{b1006}.{PfhuA}.{rbs_lholin!}.{b0015}.{PrrnB_P1}.{rbs_lantiholin!}.{Bca1041}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{tLysozyme!}.{b1006}.{Pspv}.{rbs1-A}.{tholin!}.{b0015}.{Phns}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a~tLysozyme!}.{b1006}.{Pspv}.{rbsa~}.{a~tholin!}.{b0015}.{Phns}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbs_tLysozyme!}.{b1006}.{Pspv}.{rbs_tholin!}.{b0015}.{Phns}.{rbs_tantiholin!}.{Bca1041}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{tLysozyme!}.{b1006}.{Pspv}.{rbs1-A}.{tholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{tantiholin!}.{Bca1041}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a~tLysozyme!}.{b1006}.{Pspv}.{rbsa~}.{a~tholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~tantiholin!}.{Bca1041}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbs_tLysozyme!}.{b1006}.{Pspv}.{rbs_tholin!}.{b0015}.{PrrnB_P1}.{rbs_tantiholin!}.{Bca1041}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{lLysozyme!}.{b1006}.{Pspv}.{rbs1-A}.{lholin!}.{b0015}.{Phns}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a~lLysozyme!}.{b1006}.{Pspv}.{rbsa~}.{a~lholin!}.{b0015}.{Phns}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbs_lLysozyme!}.{b1006}.{Pspv}.{rbs_lholin!}.{b0015}.{Phns}.{rbs_lantiholin!}.{Bca1041}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbs1-A}.{lLysozyme!}.{b1006}.{Pspv}.{rbs1-A}.{lholin!}.{b0015}.{PrrnB_P1}.{rbs1-A}.{lantiholin!}.{Bca1041}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbsa~}.{a~lLysozyme!}.{b1006}.{Pspv}.{rbsa~}.{a~lholin!}.{b0015}.{PrrnB_P1}.{rbsa~}.{a~lantiholin!}.{Bca1041}
{Pdps}.{rbs_spvR!}.{Pspv2}.{rbs_lLysozyme!}.{b1006}.{Pspv}.{rbs_lholin!}.{b0015}.{PrrnB_P1}.{rbs_lantiholin!}.{Bca1041}
{Psound}.{rbs1-A}.{BglII!}.{rbs1-A}.{cre!}.{b1006}
{Psound}.{rbsa~}.{a~BglII!}.{rbsa~}.{a~cre!}.{b1006}
{Psound}.{rbs_BglII!}.{rbs_cre!}.{b1006}
{Psound}.{rbs1-A}.{BglII!}.{rbs1-A}.{ligase!}.{b1006}
{Psound}.{rbsa~}.{a~BglII!}.{rbsa~}.{a~ligase!}.{b1006}
{Psound}.{rbs_BglII!}.{rbs_ligase!}.{b1006}
{Psound}.{rbs1-A}.{BglII!}.{rbs1-A}.{ligase!}.{rbs1-A}.{cre!}.{b1006}
{Psound}.{rbsa~}.{a~BglII!}.{rbsa~}.{a~ligase!}.{rbsa~}.{a~cre!}.{b1006}
{Psound}.{rbs_BglII!}.{rbs_ligase!}.{rbs_cre!}.{b1006}
{Pbad}.{rbs1-A}.{BglII!}.{rbs1-A}.{cre!}.{b1006}
{Pbad}.{rbsa~}.{a~BglII!}.{rbsa~}.{a~cre!}.{b1006}
{Pbad}.{rbs_BglII!}.{rbs_cre!}.{b1006}
{Pbad}.{rbs1-A}.{BglII!}.{rbs1-A}.{ligase!}.{b1006}
{Pbad}.{rbsa~}.{a~BglII!}.{rbsa~}.{a~ligase!}.{b1006}
{Pbad}.{rbs_BglII!}.{rbs_ligase!}.{b1006}
{Pbad}.{rbs1-A}.{BglII!}.{rbs1-A}.{ligase!}.{rbs1-A}.{cre!}.{b1006}
{Pbad}.{rbsa~}.{a~BglII!}.{rbsa~}.{a~ligase!}.{rbsa~}.{a~cre!}.{b1006}
{Pbad}.{rbs_BglII!}.{rbs_ligase!}.{rbs_cre!}.{b1006}
{Psound}.{rbs1-A}.{BamHI!}.{rbs1-A}.{cre!}.{b1006}
{Psound}.{rbsa~}.{a~BamHI!}.{rbsa~}.{a~cre!}.{b1006}
{Psound}.{rbs_BamHI!}.{rbs_cre!}.{b1006}
{Psound}.{rbs1-A}.{BamHI!}.{rbs1-A}.{ligase!}.{b1006}
{Psound}.{rbsa~}.{a~BamHI!}.{rbsa~}.{a~ligase!}.{b1006}
{Psound}.{rbs_BamHI!}.{rbs_ligase!}.{b1006}
{Psound}.{rbs1-A}.{BamHI!}.{rbs1-A}.{ligase!}.{rbs1-A}.{cre!}.{b1006}
{Psound}.{rbsa~}.{a~BamHI!}.{rbsa~}.{a~ligase!}.{rbsa~}.{a~cre!}.{b1006}
{Psound}.{rbs_BamHI!}.{rbs_ligase!}.{rbs_cre!}.{b1006}
{Pbad}.{rbs1-A}.{BamHI!}.{rbs1-A}.{cre!}.{b1006}
{Pbad}.{rbsa~}.{a~BamHI!}.{rbsa~}.{a~cre!}.{b1006}
{Pbad}.{rbs_BamHI!}.{rbs_cre!}.{b1006}
{Pbad}.{rbs1-A}.{BamHI!}.{rbs1-A}.{ligase!}.{b1006}
{Pbad}.{rbsa~}.{a~BamHI!}.{rbsa~}.{a~ligase!}.{b1006}
{Pbad}.{rbs_BamHI!}.{rbs_ligase!}.{b1006}
{Pbad}.{rbs1-A}.{BamHI!}.{rbs1-A}.{ligase!}.{rbs1-A}.{cre!}.{b1006}
{Pbad}.{rbsa~}.{a~BamHI!}.{rbsa~}.{a~ligase!}.{rbsa~}.{a~cre!}.{b1006}
{Pbad}.{rbs_BamHI!}.{rbs_ligase!}.{rbs_cre!}.{b1006}
{Psound}.{rbs1-A}.{lamB>}.{<BglII!}.{rbs1-A}.{ompT>}.{<cre!}.{b1006}
{Psound}.{rbsa~}.{a~lamB>}.{<BglII!}.{rbsa~}.{a~ompT>}.{<cre!}.{b1006}
{Psound}.{rbs_lamB>}.{<BglII!}.{rbs_ompT>}.{<cre!}.{b1006}
{Psound}.{rbs1-A}.{lamB>}.{<BglII!}.{rbs1-A}.{pelB>}.{<ligase!}.{b1006}
{Psound}.{rbsa~}.{a~lamB>}.{<BglII!}.{rbsa~}.{a~pelB>}.{<ligase!}.{b1006}
{Psound}.{rbs_lamB>}.{<BglII!}.{rbs_pelB>}.{<ligase!}.{b1006}
{Psound}.{rbs1-A}.{lamB>}.{<BglII!}.{rbs1-A}.{pelB>}.{<ligase!}.{rbs1-A}.{ompT>}.{<cre!}.{b1006}
{Psound}.{rbsa~}.{a~lamB>}.{<BglII!}.{rbsa~}.{a~pelB>}.{<ligase!}.{rbsa~}.{a~ompT>}.{<cre!}.{b1006}
{Psound}.{rbs_lamB>}.{<BglII!}.{rbs_pelB>}.{<ligase!}.{rbs_ompT>}.{<cre!}.{b1006}
{Pbad}.{rbs1-A}.{lamB>}.{<BglII!}.{rbs1-A}.{ompT>}.{<cre!}.{b1006}
{Pbad}.{rbsa~}.{a~lamB>}.{<BglII!}.{rbsa~}.{a~ompT>}.{<cre!}.{b1006}
{Pbad}.{rbs_lamB>}.{<BglII!}.{rbs_ompT>}.{<cre!}.{b1006}
{Pbad}.{rbs1-A}.{lamB>}.{<BglII!}.{rbs1-A}.{pelB>}.{<ligase!}.{b1006}
{Pbad}.{rbsa~}.{a~lamB>}.{<BglII!}.{rbsa~}.{a~pelB>}.{<ligase!}.{b1006}
{Pbad}.{rbs_lamB>}.{<BglII!}.{rbs_pelB>}.{<ligase!}.{b1006}
{Pbad}.{rbs1-A}.{lamB>}.{<BglII!}.{rbs1-A}.{pelB>}.{<ligase!}.{rbs1-A}.{ompT>}.{<cre!}.{b1006}
{Pbad}.{rbsa~}.{a~lamB>}.{<BglII!}.{rbsa~}.{a~pelB>}.{<ligase!}.{rbsa~}.{a~ompT>}.{<cre!}.{b1006}
{Pbad}.{rbs_lamB>}.{<BglII!}.{rbs_pelB>}.{<ligase!}.{rbs_ompT>}.{<cre!}.{b1006}
{Psound}.{rbs1-A}.{phoApp>}.{<BamHI!}.{rbs1-A}.{ompT>}.{<cre!}.{b1006}
{Psound}.{rbsa~}.{a~phoApp>}.{<BamHI!}.{rbsa~}.{a~ompT>}.{<cre!}.{b1006}
{Psound}.{rbs_phoApp>}.{<BamHI!}.{rbs_ompT>}.{<cre!}.{b1006}
{Psound}.{rbs1-A}.{phoApp>}.{<BamHI!}.{rbs1-A}.{pelB>}.{<ligase!}.{b1006}
{Psound}.{rbsa~}.{a~phoApp>}.{<BamHI!}.{rbsa~}.{a~pelB>}.{<ligase!}.{b1006}
{Psound}.{rbs_phoApp>}.{<BamHI!}.{rbs_pelB>}.{<ligase!}.{b1006}
{Psound}.{rbs1-A}.{phoApp>}.{<BamHI!}.{rbs1-A}.{pelB>}.{<ligase!}.{rbs1-A}.{ompT>}.{<cre!}.{b1006}
{Psound}.{rbsa~}.{a~phoApp>}.{<BamHI!}.{rbsa~}.{a~pelB>}.{<ligase!}.{rbsa~}.{a~ompT>}.{<cre!}.{b1006}
{Psound}.{rbs_phoApp>}.{<BamHI!}.{rbs_pelB>}.{<ligase!}.{rbs_ompT>}.{<cre!}.{b1006}
{Pbad}.{rbs1-A}.{phoApp>}.{<BamHI!}.{rbs1-A}.{ompT>}.{<cre!}.{b1006}
{Pbad}.{rbsa~}.{a~phoApp>}.{<BamHI!}.{rbsa~}.{a~ompT>}.{<cre!}.{b1006}
{Pbad}.{rbs_phoApp>}.{<BamHI!}.{rbs_ompT>}.{<cre!}.{b1006}
{Pbad}.{rbs1-A}.{phoApp>}.{<BamHI!}.{rbs1-A}.{pelB>}.{<ligase!}.{b1006}
{Pbad}.{rbsa~}.{a~phoApp>}.{<BamHI!}.{rbsa~}.{a~pelB>}.{<ligase!}.{b1006}
{Pbad}.{rbs_phoApp>}.{<BamHI!}.{rbs_pelB>}.{<ligase!}.{b1006}
{Pbad}.{rbs1-A}.{phoApp>}.{<BamHI!}.{rbs1-A}.{pelB>}.{<ligase!}.{rbs1-A}.{ompT>}.{<cre!}.{b1006}
{Pbad}.{rbsa~}.{a~phoApp>}.{<BamHI!}.{rbsa~}.{a~pelB>}.{<ligase!}.{rbsa~}.{a~ompT>}.{<cre!}.{b1006}
{Pbad}.{rbs_phoApp>}.{<BamHI!}.{rbs_pelB>}.{<ligase!}.{rbs_ompT>}.{<cre!}.{b1006}
	'''
	return map(hashable, [s.split('.') for s in iGEM_2008.strip().split('\n')])


# libraries from [2]

def example():
	return [
(('a',),('b',),('e',),),
(('a',),('b',),('d',),('e',),),
(('a',),('c',),('d',),('e',),),
(('a',),('d',),('e',),),
	]

def ukb(): 
	return [
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(15,),(4,),(5,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(16,),(4,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(16,),(4,),(5,),(6,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(16,),(4,),(5,),(6,),(7,),(8,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(16,),(4,),(5,),(6,),(7,),(8,),(9,),(8,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(16,),(4,),(5,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(17,),(3,),(15,),(18,),(15,),(4,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(17,),(3,),(15,),(4,),(5,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(17,),(3,),(15,),(4,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(17,),(3,),(15,),(4,),(5,),(6,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(17,),(3,),(15,),(4,),(5,),(6,),(7,),(8,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(17,),(3,),(15,),(4,),(5,),(6,),(7,),(8,),(9,),(8,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(17,),(3,),(15,),(4,),(5,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(15,),(18,),(15,),(4,),(5,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(15,),(18,),(15,),(4,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(15,),(18,),(15,),(4,),(5,),(6,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(15,),(18,),(15,),(4,),(5,),(6,),(7,),(8,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(15,),(18,),(15,),(4,),(5,),(6,),(7,),(8,),(9,),(8,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(15,),(18,),(15,),(4,),(5,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(19,),(3,),(20,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(19,),(3,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(19,),(3,),(20,),(6,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(19,),(3,),(20,),(6,),(7,),(8,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(19,),(3,),(20,),(6,),(7,),(8,),(9,),(8,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(19,),(3,),(20,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(3,),(20,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(3,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(12,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(5,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(20,),(3,),(19,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(20,),(3,),(19,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(5,),(6,),(8,),(9,),(8,),(10,),(11,),(20,),(3,),(19,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(5,),(6,),(7,),(8,),(8,),(10,),(11,),(20,),(3,),(19,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(5,),(6,),(7,),(8,),(9,),(8,),(11,),(20,),(3,),(19,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(5,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(3,),(19,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(5,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(20,),(3,),(13,),(14,),(0,),),
((0,),(1,),(2,),(3,),(5,),(6,),(7,),(8,),(9,),(8,),(10,),(11,),(3,),(13,),(14,),(0,),)
	]

def unott_azurin():
	return [
((0,),(1,),(2,),(3,),(4,),(5,),(6,),),
((0,),(1,),(2,),(3,),(4,),(7,),(6,),),
((0,),(1,),(2,),(3,),(4,),(8,),(6,),),
((0,),(1,),(2,),(3,),(4,),(9,),(6,),),
((0,),(1,),(2,),(3,),(4,),(10,),(6,),),
((0,),(1,),(2,),(11,),(4,),(5,),(6,),),
((0,),(1,),(2,),(11,),(4,),(7,),(6,),),
((0,),(1,),(2,),(11,),(4,),(8,),(6,),),
((0,),(1,),(2,),(11,),(4,),(9,),(6,),),
((0,),(1,),(2,),(11,),(4,),(10,),(6,),),
((0,),(1,),(2,),(12,),(4,),(5,),(6,),),
((0,),(1,),(2,),(12,),(4,),(7,),(6,),),
((0,),(1,),(2,),(12,),(4,),(8,),(6,),),
((0,),(1,),(2,),(12,),(4,),(9,),(6,),),
((0,),(1,),(2,),(12,),(4,),(10,),(6,),),
((0,),(1,),(2,),(13,),(4,),(5,),(6,),),
((0,),(1,),(2,),(13,),(4,),(7,),(6,),),
((0,),(1,),(2,),(13,),(4,),(8,),(6,),),
((0,),(1,),(2,),(13,),(4,),(9,),(6,),),
((0,),(1,),(2,),(13,),(4,),(10,),(6,),),
((0,),(1,),(2,),(14,),(4,),(5,),(6,),),
((0,),(1,),(2,),(14,),(4,),(7,),(6,),),
((0,),(1,),(2,),(14,),(4,),(8,),(6,),),
((0,),(1,),(2,),(14,),(4,),(9,),(6,),),
((0,),(1,),(2,),(14,),(4,),(10,),(6,),),
((0,),(15,),(2,),(3,),(4,),(5,),(6,),),
((0,),(15,),(2,),(3,),(4,),(7,),(6,),),
((0,),(15,),(2,),(3,),(4,),(8,),(6,),),
((0,),(15,),(2,),(3,),(4,),(9,),(6,),),
((0,),(15,),(2,),(3,),(4,),(10,),(6,),),
((0,),(15,),(2,),(11,),(4,),(5,),(6,),),
((0,),(15,),(2,),(11,),(4,),(7,),(6,),),
((0,),(15,),(2,),(11,),(4,),(8,),(6,),),
((0,),(15,),(2,),(11,),(4,),(9,),(6,),),
((0,),(15,),(2,),(11,),(4,),(10,),(6,),),
((0,),(15,),(2,),(12,),(4,),(5,),(6,),),
((0,),(15,),(2,),(12,),(4,),(7,),(6,),),
((0,),(15,),(2,),(12,),(4,),(8,),(6,),),
((0,),(15,),(2,),(12,),(4,),(9,),(6,),),
((0,),(15,),(2,),(12,),(4,),(10,),(6,),),
((0,),(15,),(2,),(13,),(4,),(5,),(6,),),
((0,),(15,),(2,),(13,),(4,),(7,),(6,),),
((0,),(15,),(2,),(13,),(4,),(8,),(6,),),
((0,),(15,),(2,),(13,),(4,),(9,),(6,),),
((0,),(15,),(2,),(13,),(4,),(10,),(6,),),
((0,),(15,),(2,),(14,),(4,),(5,),(6,),),
((0,),(15,),(2,),(14,),(4,),(7,),(6,),),
((0,),(15,),(2,),(14,),(4,),(8,),(6,),),
((0,),(15,),(2,),(14,),(4,),(9,),(6,),),
((0,),(15,),(2,),(14,),(4,),(10,),(6,),),
((0,),(16,),(2,),(3,),(4,),(5,),(6,),),
((0,),(16,),(2,),(3,),(4,),(7,),(6,),),
((0,),(16,),(2,),(3,),(4,),(8,),(6,),),
((0,),(16,),(2,),(3,),(4,),(9,),(6,),),
((0,),(16,),(2,),(3,),(4,),(10,),(6,),),
((0,),(16,),(2,),(11,),(4,),(5,),(6,),),
((0,),(16,),(2,),(11,),(4,),(7,),(6,),),
((0,),(16,),(2,),(11,),(4,),(8,),(6,),),
((0,),(16,),(2,),(11,),(4,),(9,),(6,),),
((0,),(16,),(2,),(11,),(4,),(10,),(6,),),
((0,),(16,),(2,),(12,),(4,),(5,),(6,),),
((0,),(16,),(2,),(12,),(4,),(7,),(6,),),
((0,),(16,),(2,),(12,),(4,),(8,),(6,),),
((0,),(16,),(2,),(12,),(4,),(9,),(6,),),
((0,),(16,),(2,),(12,),(4,),(10,),(6,),),
((0,),(16,),(2,),(13,),(4,),(5,),(6,),),
((0,),(16,),(2,),(13,),(4,),(7,),(6,),),
((0,),(16,),(2,),(13,),(4,),(8,),(6,),),
((0,),(16,),(2,),(13,),(4,),(9,),(6,),),
((0,),(16,),(2,),(13,),(4,),(10,),(6,),),
((0,),(16,),(2,),(14,),(4,),(5,),(6,),),
((0,),(16,),(2,),(14,),(4,),(7,),(6,),),
((0,),(16,),(2,),(14,),(4,),(8,),(6,),),
((0,),(16,),(2,),(14,),(4,),(9,),(6,),),
((0,),(16,),(2,),(14,),(4,),(10,),(6,),),
((0,),(17,),(2,),(3,),(4,),(5,),(6,),),
((0,),(17,),(2,),(3,),(4,),(7,),(6,),),
((0,),(17,),(2,),(3,),(4,),(8,),(6,),),
((0,),(17,),(2,),(3,),(4,),(9,),(6,),),
((0,),(17,),(2,),(3,),(4,),(10,),(6,),),
((0,),(17,),(2,),(11,),(4,),(5,),(6,),),
((0,),(17,),(2,),(11,),(4,),(7,),(6,),),
((0,),(17,),(2,),(11,),(4,),(8,),(6,),),
((0,),(17,),(2,),(11,),(4,),(9,),(6,),),
((0,),(17,),(2,),(11,),(4,),(10,),(6,),),
((0,),(17,),(2,),(12,),(4,),(5,),(6,),),
((0,),(17,),(2,),(12,),(4,),(7,),(6,),),
((0,),(17,),(2,),(12,),(4,),(8,),(6,),),
((0,),(17,),(2,),(12,),(4,),(9,),(6,),),
((0,),(17,),(2,),(12,),(4,),(10,),(6,),),
((0,),(17,),(2,),(13,),(4,),(5,),(6,),),
((0,),(17,),(2,),(13,),(4,),(7,),(6,),),
((0,),(17,),(2,),(13,),(4,),(8,),(6,),),
((0,),(17,),(2,),(13,),(4,),(9,),(6,),),
((0,),(17,),(2,),(13,),(4,),(10,),(6,),),
((0,),(17,),(2,),(14,),(4,),(5,),(6,),),
((0,),(17,),(2,),(14,),(4,),(7,),(6,),),
((0,),(17,),(2,),(14,),(4,),(8,),(6,),),
((0,),(17,),(2,),(14,),(4,),(9,),(6,),),
((0,),(17,),(2,),(14,),(4,),(10,),(6,),),
((0,),(18,),(2,),(3,),(4,),(5,),(6,),),
((0,),(18,),(2,),(3,),(4,),(7,),(6,),),
((0,),(18,),(2,),(3,),(4,),(8,),(6,),),
((0,),(18,),(2,),(3,),(4,),(9,),(6,),),
((0,),(18,),(2,),(3,),(4,),(10,),(6,),),
((0,),(18,),(2,),(11,),(4,),(5,),(6,),),
((0,),(18,),(2,),(11,),(4,),(7,),(6,),),
((0,),(18,),(2,),(11,),(4,),(8,),(6,),),
((0,),(18,),(2,),(11,),(4,),(9,),(6,),),
((0,),(18,),(2,),(11,),(4,),(10,),(6,),),
((0,),(18,),(2,),(12,),(4,),(5,),(6,),),
((0,),(18,),(2,),(12,),(4,),(7,),(6,),),
((0,),(18,),(2,),(12,),(4,),(8,),(6,),),
((0,),(18,),(2,),(12,),(4,),(9,),(6,),),
((0,),(18,),(2,),(12,),(4,),(10,),(6,),),
((0,),(18,),(2,),(13,),(4,),(5,),(6,),),
((0,),(18,),(2,),(13,),(4,),(7,),(6,),),
((0,),(18,),(2,),(13,),(4,),(8,),(6,),),
((0,),(18,),(2,),(13,),(4,),(9,),(6,),),
((0,),(18,),(2,),(13,),(4,),(10,),(6,),),
((0,),(18,),(2,),(14,),(4,),(5,),(6,),),
((0,),(18,),(2,),(14,),(4,),(7,),(6,),),
((0,),(18,),(2,),(14,),(4,),(8,),(6,),),
((0,),(18,),(2,),(14,),(4,),(9,),(6,),),
((0,),(18,),(2,),(14,),(4,),(10,),(6,),)
	]

def uh1():
	return [
((0,),(1,),(2,),(3,),(4,),(5,),),
((0,),(1,),(2,),(6,),(4,),(5,),),
((0,),(1,),(2,),(7,),(4,),(5,),),
((0,),(1,),(2,),(8,),(4,),(5,),),
((0,),(1,),(9,),(3,),(4,),(5,),),
((0,),(1,),(9,),(6,),(4,),(5,),),
((0,),(1,),(9,),(7,),(4,),(5,),),
((0,),(1,),(9,),(8,),(4,),(5,),),
((0,),(1,),(10,),(3,),(4,),(5,),),
((0,),(1,),(10,),(6,),(4,),(5,),),
((0,),(1,),(10,),(7,),(4,),(5,),),
((0,),(1,),(10,),(8,),(4,),(5,),),
((0,),(1,),(11,),(3,),(4,),(5,),),
((0,),(1,),(11,),(6,),(4,),(5,),),
((0,),(1,),(11,),(7,),(4,),(5,),),
((0,),(1,),(11,),(8,),(4,),(5,),),
((0,),(12,),(2,),(3,),(4,),(5,),),
((0,),(12,),(2,),(6,),(4,),(5,),),
((0,),(12,),(2,),(7,),(4,),(5,),),
((0,),(12,),(2,),(8,),(4,),(5,),),
((0,),(12,),(9,),(3,),(4,),(5,),),
((0,),(12,),(9,),(6,),(4,),(5,),),
((0,),(12,),(9,),(7,),(4,),(5,),),
((0,),(12,),(9,),(8,),(4,),(5,),),
((0,),(12,),(10,),(3,),(4,),(5,),),
((0,),(12,),(10,),(6,),(4,),(5,),),
((0,),(12,),(10,),(7,),(4,),(5,),),
((0,),(12,),(10,),(8,),(4,),(5,),),
((0,),(12,),(11,),(3,),(4,),(5,),),
((0,),(12,),(11,),(6,),(4,),(5,),),
((0,),(12,),(11,),(7,),(4,),(5,),),
((0,),(12,),(11,),(8,),(4,),(5,),),
((0,),(13,),(2,),(3,),(4,),(5,),),
((0,),(13,),(2,),(6,),(4,),(5,),),
((0,),(13,),(2,),(7,),(4,),(5,),),
((0,),(13,),(2,),(8,),(4,),(5,),),
((0,),(13,),(9,),(3,),(4,),(5,),),
((0,),(13,),(9,),(6,),(4,),(5,),),
((0,),(13,),(9,),(7,),(4,),(5,),),
((0,),(13,),(9,),(8,),(4,),(5,),),
((0,),(13,),(10,),(3,),(4,),(5,),),
((0,),(13,),(10,),(6,),(4,),(5,),),
((0,),(13,),(10,),(7,),(4,),(5,),),
((0,),(13,),(10,),(8,),(4,),(5,),),
((0,),(13,),(11,),(3,),(4,),(5,),),
((0,),(13,),(11,),(6,),(4,),(5,),),
((0,),(13,),(11,),(7,),(4,),(5,),),
((0,),(13,),(11,),(8,),(4,),(5,),),
((0,),(14,),(2,),(3,),(4,),(5,),),
((0,),(14,),(2,),(6,),(4,),(5,),),
((0,),(14,),(2,),(7,),(4,),(5,),),
((0,),(14,),(2,),(8,),(4,),(5,),),
((0,),(14,),(9,),(3,),(4,),(5,),),
((0,),(14,),(9,),(6,),(4,),(5,),),
((0,),(14,),(9,),(7,),(4,),(5,),),
((0,),(14,),(9,),(8,),(4,),(5,),),
((0,),(14,),(10,),(3,),(4,),(5,),),
((0,),(14,),(10,),(6,),(4,),(5,),),
((0,),(14,),(10,),(7,),(4,),(5,),),
((0,),(14,),(10,),(8,),(4,),(5,),),
((0,),(14,),(11,),(3,),(4,),(5,),),
((0,),(14,),(11,),(6,),(4,),(5,),),
((0,),(14,),(11,),(7,),(4,),(5,),),
((0,),(14,),(11,),(8,),(4,),(5,),),
((0,),(1,),(2,),(3,),(15,),(5,),),
((0,),(1,),(2,),(6,),(15,),(5,),),
((0,),(1,),(2,),(7,),(15,),(5,),),
((0,),(1,),(2,),(8,),(15,),(5,),),
((0,),(1,),(9,),(3,),(15,),(5,),),
((0,),(1,),(9,),(6,),(15,),(5,),),
((0,),(1,),(9,),(7,),(15,),(5,),),
((0,),(1,),(9,),(8,),(15,),(5,),),
((0,),(1,),(10,),(3,),(15,),(5,),),
((0,),(1,),(10,),(6,),(15,),(5,),),
((0,),(1,),(10,),(7,),(15,),(5,),),
((0,),(1,),(10,),(8,),(15,),(5,),),
((0,),(1,),(11,),(3,),(15,),(5,),),
((0,),(1,),(11,),(6,),(15,),(5,),),
((0,),(1,),(11,),(7,),(15,),(5,),),
((0,),(1,),(11,),(8,),(15,),(5,),),
((0,),(12,),(2,),(3,),(15,),(5,),),
((0,),(12,),(2,),(6,),(15,),(5,),),
((0,),(12,),(2,),(7,),(15,),(5,),),
((0,),(12,),(2,),(8,),(15,),(5,),),
((0,),(12,),(9,),(3,),(15,),(5,),),
((0,),(12,),(9,),(6,),(15,),(5,),),
((0,),(12,),(9,),(7,),(15,),(5,),),
((0,),(12,),(9,),(8,),(15,),(5,),),
((0,),(12,),(10,),(3,),(15,),(5,),),
((0,),(12,),(10,),(6,),(15,),(5,),),
((0,),(12,),(10,),(7,),(15,),(5,),),
((0,),(12,),(10,),(8,),(15,),(5,),),
((0,),(12,),(11,),(3,),(15,),(5,),),
((0,),(12,),(11,),(6,),(15,),(5,),),
((0,),(12,),(11,),(7,),(15,),(5,),),
((0,),(12,),(11,),(8,),(15,),(5,),),
((0,),(13,),(2,),(3,),(15,),(5,),),
((0,),(13,),(2,),(6,),(15,),(5,),),
((0,),(13,),(2,),(7,),(15,),(5,),),
((0,),(13,),(2,),(8,),(15,),(5,),),
((0,),(13,),(9,),(3,),(15,),(5,),),
((0,),(13,),(9,),(6,),(15,),(5,),),
((0,),(13,),(9,),(7,),(15,),(5,),),
((0,),(13,),(9,),(8,),(15,),(5,),),
((0,),(13,),(10,),(3,),(15,),(5,),),
((0,),(13,),(10,),(6,),(15,),(5,),),
((0,),(13,),(10,),(7,),(15,),(5,),),
((0,),(13,),(10,),(8,),(15,),(5,),),
((0,),(13,),(11,),(3,),(15,),(5,),),
((0,),(13,),(11,),(6,),(15,),(5,),),
((0,),(13,),(11,),(7,),(15,),(5,),),
((0,),(13,),(11,),(8,),(15,),(5,),),
((0,),(14,),(2,),(3,),(15,),(5,),),
((0,),(14,),(2,),(6,),(15,),(5,),),
((0,),(14,),(2,),(7,),(15,),(5,),),
((0,),(14,),(2,),(8,),(15,),(5,),),
((0,),(14,),(9,),(3,),(15,),(5,),),
((0,),(14,),(9,),(6,),(15,),(5,),),
((0,),(14,),(9,),(7,),(15,),(5,),),
((0,),(14,),(9,),(8,),(15,),(5,),),
((0,),(14,),(10,),(3,),(15,),(5,),),
((0,),(14,),(10,),(6,),(15,),(5,),),
((0,),(14,),(10,),(7,),(15,),(5,),),
((0,),(14,),(10,),(8,),(15,),(5,),),
((0,),(14,),(11,),(3,),(15,),(5,),),
((0,),(14,),(11,),(6,),(15,),(5,),),
((0,),(14,),(11,),(7,),(15,),(5,),),
((0,),(14,),(11,),(8,),(15,),(5,),),
((0,),(1,),(2,),(3,),(16,),(5,),),
((0,),(1,),(2,),(6,),(16,),(5,),),
((0,),(1,),(2,),(7,),(16,),(5,),),
((0,),(1,),(2,),(8,),(16,),(5,),),
((0,),(1,),(9,),(3,),(16,),(5,),),
((0,),(1,),(9,),(6,),(16,),(5,),),
((0,),(1,),(9,),(7,),(16,),(5,),),
((0,),(1,),(9,),(8,),(16,),(5,),),
((0,),(1,),(10,),(3,),(16,),(5,),),
((0,),(1,),(10,),(6,),(16,),(5,),),
((0,),(1,),(10,),(7,),(16,),(5,),),
((0,),(1,),(10,),(8,),(16,),(5,),),
((0,),(1,),(11,),(3,),(16,),(5,),),
((0,),(1,),(11,),(6,),(16,),(5,),),
((0,),(1,),(11,),(7,),(16,),(5,),),
((0,),(1,),(11,),(8,),(16,),(5,),),
((0,),(12,),(2,),(3,),(16,),(5,),),
((0,),(12,),(2,),(6,),(16,),(5,),),
((0,),(12,),(2,),(7,),(16,),(5,),),
((0,),(12,),(2,),(8,),(16,),(5,),),
((0,),(12,),(9,),(3,),(16,),(5,),),
((0,),(12,),(9,),(6,),(16,),(5,),),
((0,),(12,),(9,),(7,),(16,),(5,),),
((0,),(12,),(9,),(8,),(16,),(5,),),
((0,),(12,),(10,),(3,),(16,),(5,),),
((0,),(12,),(10,),(6,),(16,),(5,),),
((0,),(12,),(10,),(7,),(16,),(5,),),
((0,),(12,),(10,),(8,),(16,),(5,),),
((0,),(12,),(11,),(3,),(16,),(5,),),
((0,),(12,),(11,),(6,),(16,),(5,),),
((0,),(12,),(11,),(7,),(16,),(5,),),
((0,),(12,),(11,),(8,),(16,),(5,),),
((0,),(13,),(2,),(3,),(16,),(5,),),
((0,),(13,),(2,),(6,),(16,),(5,),),
((0,),(13,),(2,),(7,),(16,),(5,),),
((0,),(13,),(2,),(8,),(16,),(5,),),
((0,),(13,),(9,),(3,),(16,),(5,),),
((0,),(13,),(9,),(6,),(16,),(5,),),
((0,),(13,),(9,),(7,),(16,),(5,),),
((0,),(13,),(9,),(8,),(16,),(5,),),
((0,),(13,),(10,),(3,),(16,),(5,),),
((0,),(13,),(10,),(6,),(16,),(5,),),
((0,),(13,),(10,),(7,),(16,),(5,),),
((0,),(13,),(10,),(8,),(16,),(5,),),
((0,),(13,),(11,),(3,),(16,),(5,),),
((0,),(13,),(11,),(6,),(16,),(5,),),
((0,),(13,),(11,),(7,),(16,),(5,),),
((0,),(13,),(11,),(8,),(16,),(5,),),
((0,),(14,),(2,),(3,),(16,),(5,),),
((0,),(14,),(2,),(6,),(16,),(5,),),
((0,),(14,),(2,),(7,),(16,),(5,),),
((0,),(14,),(2,),(8,),(16,),(5,),),
((0,),(14,),(9,),(3,),(16,),(5,),),
((0,),(14,),(9,),(6,),(16,),(5,),),
((0,),(14,),(9,),(7,),(16,),(5,),),
((0,),(14,),(9,),(8,),(16,),(5,),),
((0,),(14,),(10,),(3,),(16,),(5,),),
((0,),(14,),(10,),(6,),(16,),(5,),),
((0,),(14,),(10,),(7,),(16,),(5,),),
((0,),(14,),(10,),(8,),(16,),(5,),),
((0,),(14,),(11,),(3,),(16,),(5,),),
((0,),(14,),(11,),(6,),(16,),(5,),),
((0,),(14,),(11,),(7,),(16,),(5,),),
((0,),(14,),(11,),(8,),(16,),(5,),),
((0,),(1,),(2,),(3,),(17,),(5,),),
((0,),(1,),(2,),(6,),(17,),(5,),),
((0,),(1,),(2,),(7,),(17,),(5,),),
((0,),(1,),(2,),(8,),(17,),(5,),),
((0,),(1,),(9,),(3,),(17,),(5,),),
((0,),(1,),(9,),(6,),(17,),(5,),),
((0,),(1,),(9,),(7,),(17,),(5,),),
((0,),(1,),(9,),(8,),(17,),(5,),),
((0,),(1,),(10,),(3,),(17,),(5,),),
((0,),(1,),(10,),(6,),(17,),(5,),),
((0,),(1,),(10,),(7,),(17,),(5,),),
((0,),(1,),(10,),(8,),(17,),(5,),),
((0,),(1,),(11,),(3,),(17,),(5,),),
((0,),(1,),(11,),(6,),(17,),(5,),),
((0,),(1,),(11,),(7,),(17,),(5,),),
((0,),(1,),(11,),(8,),(17,),(5,),),
((0,),(12,),(2,),(3,),(17,),(5,),),
((0,),(12,),(2,),(6,),(17,),(5,),),
((0,),(12,),(2,),(7,),(17,),(5,),),
((0,),(12,),(2,),(8,),(17,),(5,),),
((0,),(12,),(9,),(3,),(17,),(5,),),
((0,),(12,),(9,),(6,),(17,),(5,),),
((0,),(12,),(9,),(7,),(17,),(5,),),
((0,),(12,),(9,),(8,),(17,),(5,),),
((0,),(12,),(10,),(3,),(17,),(5,),),
((0,),(12,),(10,),(6,),(17,),(5,),),
((0,),(12,),(10,),(7,),(17,),(5,),),
((0,),(12,),(10,),(8,),(17,),(5,),),
((0,),(12,),(11,),(3,),(17,),(5,),),
((0,),(12,),(11,),(6,),(17,),(5,),),
((0,),(12,),(11,),(7,),(17,),(5,),),
((0,),(12,),(11,),(8,),(17,),(5,),),
((0,),(13,),(2,),(3,),(17,),(5,),),
((0,),(13,),(2,),(6,),(17,),(5,),),
((0,),(13,),(2,),(7,),(17,),(5,),),
((0,),(13,),(2,),(8,),(17,),(5,),),
((0,),(13,),(9,),(3,),(17,),(5,),),
((0,),(13,),(9,),(6,),(17,),(5,),),
((0,),(13,),(9,),(7,),(17,),(5,),),
((0,),(13,),(9,),(8,),(17,),(5,),),
((0,),(13,),(10,),(3,),(17,),(5,),),
((0,),(13,),(10,),(6,),(17,),(5,),),
((0,),(13,),(10,),(7,),(17,),(5,),),
((0,),(13,),(10,),(8,),(17,),(5,),),
((0,),(13,),(11,),(3,),(17,),(5,),),
((0,),(13,),(11,),(6,),(17,),(5,),),
((0,),(13,),(11,),(7,),(17,),(5,),),
((0,),(13,),(11,),(8,),(17,),(5,),),
((0,),(14,),(2,),(3,),(17,),(5,),),
((0,),(14,),(2,),(6,),(17,),(5,),),
((0,),(14,),(2,),(7,),(17,),(5,),),
((0,),(14,),(2,),(8,),(17,),(5,),),
((0,),(14,),(9,),(3,),(17,),(5,),),
((0,),(14,),(9,),(6,),(17,),(5,),),
((0,),(14,),(9,),(7,),(17,),(5,),),
((0,),(14,),(9,),(8,),(17,),(5,),),
((0,),(14,),(10,),(3,),(17,),(5,),),
((0,),(14,),(10,),(6,),(17,),(5,),),
((0,),(14,),(10,),(7,),(17,),(5,),),
((0,),(14,),(10,),(8,),(17,),(5,),),
((0,),(14,),(11,),(3,),(17,),(5,),),
((0,),(14,),(11,),(6,),(17,),(5,),),
((0,),(14,),(11,),(7,),(17,),(5,),),
((0,),(14,),(11,),(8,),(17,),(5,),)
		]
	
def uh2():
	return [
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(5,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(5,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(5,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(5,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(5,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(5,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(5,),(16,),(5,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(5,),(14,),(5,),(16,),(17,),(18,),(5,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(5,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(5,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(5,),(18,),(5,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(7,),(8,),(5,),(10,),(11,),(12,),(5,),(14,),(5,),(16,),(17,),(18,),(5,),(20,),(5,),(22,),(23,),(24,),(5,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(5,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(5,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(5,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(5,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(5,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(5,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(11,),(12,),(5,),(14,),(5,),(16,),(17,),(18,),(5,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(11,),(12,),(5,),(14,),(5,),(16,),(5,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(5,),(18,),(19,),(20,),(21,),(22,),(5,),(24,),(25,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(11,),(12,),(13,),(14,),(5,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(11,),(12,),(5,),(14,),(5,),(16,),(17,),(18,),(5,),(20,),(21,),(22,),(5,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(11,),(12,),(5,),(14,),(5,),(16,),(17,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(5,),(16,),(5,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(5,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(7,),(8,),(9,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(5,),(20,),(21,),(22,),(23,),(24,),(5,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(7,),(8,),(5,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(7,),(8,),(5,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(5,),(18,),(5,),(20,),(21,),(22,),(5,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(7,),(8,),(5,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(25,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(7,),(8,),(5,),(10,),(11,),(12,),(5,),(14,),(5,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(7,),(8,),(5,),(10,),(11,),(12,),(5,),(14,),(5,),(16,),(5,),(18,),(5,),(20,),(21,),(22,),(5,),(24,),(5,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(5,),(8,),(9,),(10,),(11,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(5,),(8,),(9,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(5,),(8,),(9,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(5,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(5,),(8,),(9,),(10,),(11,),(12,),(5,),(14,),(5,),(16,),(17,),(18,),(5,),(20,),(5,),(22,),(23,),(24,),(5,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(5,),(8,),(5,),(10,),(11,),(12,),(13,),(14,),(5,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(5,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(5,),(8,),(5,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(5,),(8,),(5,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(5,),(20,),(21,),(22,),(23,),(24,),(5,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(3,),(4,),(5,),(6,),(5,),(8,),(5,),(10,),(11,),(12,),(5,),(14,),(15,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(5,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(5,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(5,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(5,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(5,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(5,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(5,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(5,),(16,),(5,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(5,),(14,),(5,),(16,),(17,),(18,),(5,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(5,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(5,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(5,),(18,),(5,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(7,),(8,),(5,),(10,),(35,),(12,),(5,),(14,),(5,),(16,),(17,),(18,),(5,),(20,),(5,),(22,),(23,),(24,),(5,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(5,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(5,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(5,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(5,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(5,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(5,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(35,),(12,),(5,),(14,),(5,),(16,),(17,),(18,),(5,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(9,),(10,),(35,),(12,),(5,),(14,),(5,),(16,),(5,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(5,),(18,),(19,),(20,),(21,),(22,),(5,),(24,),(25,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(35,),(12,),(13,),(14,),(5,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(35,),(12,),(5,),(14,),(5,),(16,),(17,),(18,),(5,),(20,),(21,),(22,),(5,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(33,),(6,),(5,),(8,),(5,),(10,),(35,),(12,),(5,),(14,),(5,),(16,),(17,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(5,),(16,),(5,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(25,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(5,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(7,),(8,),(9,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(5,),(20,),(21,),(22,),(23,),(24,),(5,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(7,),(8,),(5,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(7,),(8,),(5,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(5,),(18,),(5,),(20,),(21,),(22,),(5,),(24,),(25,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(7,),(8,),(5,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(25,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(7,),(8,),(5,),(10,),(35,),(12,),(5,),(14,),(5,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(7,),(8,),(5,),(10,),(35,),(12,),(5,),(14,),(5,),(16,),(5,),(18,),(5,),(20,),(21,),(22,),(5,),(24,),(5,),(26,),(5,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(5,),(8,),(9,),(10,),(35,),(12,),(13,),(14,),(15,),(16,),(17,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(5,),(8,),(9,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(5,),(8,),(9,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(5,),(18,),(5,),(20,),(5,),(22,),(5,),(24,),(5,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(5,),(8,),(9,),(10,),(35,),(12,),(5,),(14,),(5,),(16,),(17,),(18,),(5,),(20,),(5,),(22,),(23,),(24,),(5,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(5,),(8,),(5,),(10,),(35,),(12,),(13,),(14,),(5,),(16,),(17,),(18,),(19,),(20,),(21,),(22,),(23,),(24,),(5,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(5,),(8,),(5,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(25,),(26,),(5,),(28,),(5,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(5,),(8,),(5,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(17,),(18,),(5,),(20,),(21,),(22,),(23,),(24,),(5,),(26,),(27,),(28,),(29,),(30,),(31,),(32,),),
((0,),(1,),(2,),(34,),(4,),(5,),(6,),(5,),(8,),(5,),(10,),(35,),(12,),(5,),(14,),(15,),(16,),(5,),(18,),(19,),(20,),(5,),(22,),(23,),(24,),(5,),(26,),(27,),(28,),(5,),(30,),(31,),(32,),)
	]

def ethz():
	return [
((0,),(1,),(2,),(1,),(3,),(1,),(4,),),
((0,),(1,),(2,),(1,),(3,),(5,),(4,),),
((0,),(1,),(2,),(1,),(3,),(6,),(4,),),
((0,),(1,),(2,),(1,),(3,),(7,),(4,),),
((0,),(1,),(2,),(1,),(3,),(8,),(4,),),
((0,),(1,),(2,),(5,),(3,),(1,),(4,),),
((0,),(1,),(2,),(5,),(3,),(5,),(4,),),
((0,),(1,),(2,),(5,),(3,),(6,),(4,),),
((0,),(1,),(2,),(5,),(3,),(7,),(4,),),
((0,),(1,),(2,),(5,),(3,),(8,),(4,),),
((0,),(1,),(2,),(6,),(3,),(1,),(4,),),
((0,),(1,),(2,),(6,),(3,),(5,),(4,),),
((0,),(1,),(2,),(6,),(3,),(6,),(4,),),
((0,),(1,),(2,),(6,),(3,),(7,),(4,),),
((0,),(1,),(2,),(6,),(3,),(8,),(4,),),
((0,),(1,),(2,),(7,),(3,),(1,),(4,),),
((0,),(1,),(2,),(7,),(3,),(5,),(4,),),
((0,),(1,),(2,),(7,),(3,),(6,),(4,),),
((0,),(1,),(2,),(7,),(3,),(7,),(4,),),
((0,),(1,),(2,),(7,),(3,),(8,),(4,),),
((0,),(1,),(2,),(8,),(3,),(1,),(4,),),
((0,),(1,),(2,),(8,),(3,),(5,),(4,),),
((0,),(1,),(2,),(8,),(3,),(6,),(4,),),
((0,),(1,),(2,),(8,),(3,),(7,),(4,),),
((0,),(1,),(2,),(8,),(3,),(8,),(4,),),
((0,),(5,),(2,),(1,),(3,),(1,),(4,),),
((0,),(5,),(2,),(1,),(3,),(5,),(4,),),
((0,),(5,),(2,),(1,),(3,),(6,),(4,),),
((0,),(5,),(2,),(1,),(3,),(7,),(4,),),
((0,),(5,),(2,),(1,),(3,),(8,),(4,),),
((0,),(5,),(2,),(5,),(3,),(1,),(4,),),
((0,),(5,),(2,),(5,),(3,),(5,),(4,),),
((0,),(5,),(2,),(5,),(3,),(6,),(4,),),
((0,),(5,),(2,),(5,),(3,),(7,),(4,),),
((0,),(5,),(2,),(5,),(3,),(8,),(4,),),
((0,),(5,),(2,),(6,),(3,),(1,),(4,),),
((0,),(5,),(2,),(6,),(3,),(5,),(4,),),
((0,),(5,),(2,),(6,),(3,),(6,),(4,),),
((0,),(5,),(2,),(6,),(3,),(7,),(4,),),
((0,),(5,),(2,),(6,),(3,),(8,),(4,),),
((0,),(5,),(2,),(7,),(3,),(1,),(4,),),
((0,),(5,),(2,),(7,),(3,),(5,),(4,),),
((0,),(5,),(2,),(7,),(3,),(6,),(4,),),
((0,),(5,),(2,),(7,),(3,),(7,),(4,),),
((0,),(5,),(2,),(7,),(3,),(8,),(4,),),
((0,),(5,),(2,),(8,),(3,),(1,),(4,),),
((0,),(5,),(2,),(8,),(3,),(5,),(4,),),
((0,),(5,),(2,),(8,),(3,),(6,),(4,),),
((0,),(5,),(2,),(8,),(3,),(7,),(4,),),
((0,),(5,),(2,),(8,),(3,),(8,),(4,),),
((0,),(6,),(2,),(1,),(3,),(1,),(4,),),
((0,),(6,),(2,),(1,),(3,),(5,),(4,),),
((0,),(6,),(2,),(1,),(3,),(6,),(4,),),
((0,),(6,),(2,),(1,),(3,),(7,),(4,),),
((0,),(6,),(2,),(1,),(3,),(8,),(4,),),
((0,),(6,),(2,),(5,),(3,),(1,),(4,),),
((0,),(6,),(2,),(5,),(3,),(5,),(4,),),
((0,),(6,),(2,),(5,),(3,),(6,),(4,),),
((0,),(6,),(2,),(5,),(3,),(7,),(4,),),
((0,),(6,),(2,),(5,),(3,),(8,),(4,),),
((0,),(6,),(2,),(6,),(3,),(1,),(4,),),
((0,),(6,),(2,),(6,),(3,),(5,),(4,),),
((0,),(6,),(2,),(6,),(3,),(6,),(4,),),
((0,),(6,),(2,),(6,),(3,),(7,),(4,),),
((0,),(6,),(2,),(6,),(3,),(8,),(4,),),
((0,),(6,),(2,),(7,),(3,),(1,),(4,),),
((0,),(6,),(2,),(7,),(3,),(5,),(4,),),
((0,),(6,),(2,),(7,),(3,),(6,),(4,),),
((0,),(6,),(2,),(7,),(3,),(7,),(4,),),
((0,),(6,),(2,),(7,),(3,),(8,),(4,),),
((0,),(6,),(2,),(8,),(3,),(1,),(4,),),
((0,),(6,),(2,),(8,),(3,),(5,),(4,),),
((0,),(6,),(2,),(8,),(3,),(6,),(4,),),
((0,),(6,),(2,),(8,),(3,),(7,),(4,),),
((0,),(6,),(2,),(8,),(3,),(8,),(4,),),
((0,),(7,),(2,),(1,),(3,),(1,),(4,),),
((0,),(7,),(2,),(1,),(3,),(5,),(4,),),
((0,),(7,),(2,),(1,),(3,),(6,),(4,),),
((0,),(7,),(2,),(1,),(3,),(7,),(4,),),
((0,),(7,),(2,),(1,),(3,),(8,),(4,),),
((0,),(7,),(2,),(5,),(3,),(1,),(4,),),
((0,),(7,),(2,),(5,),(3,),(5,),(4,),),
((0,),(7,),(2,),(5,),(3,),(6,),(4,),),
((0,),(7,),(2,),(5,),(3,),(7,),(4,),),
((0,),(7,),(2,),(5,),(3,),(8,),(4,),),
((0,),(7,),(2,),(6,),(3,),(1,),(4,),),
((0,),(7,),(2,),(6,),(3,),(5,),(4,),),
((0,),(7,),(2,),(6,),(3,),(6,),(4,),),
((0,),(7,),(2,),(6,),(3,),(7,),(4,),),
((0,),(7,),(2,),(6,),(3,),(8,),(4,),),
((0,),(7,),(2,),(7,),(3,),(1,),(4,),),
((0,),(7,),(2,),(7,),(3,),(5,),(4,),),
((0,),(7,),(2,),(7,),(3,),(6,),(4,),),
((0,),(7,),(2,),(7,),(3,),(7,),(4,),),
((0,),(7,),(2,),(7,),(3,),(8,),(4,),),
((0,),(7,),(2,),(8,),(3,),(1,),(4,),),
((0,),(7,),(2,),(8,),(3,),(5,),(4,),),
((0,),(7,),(2,),(8,),(3,),(6,),(4,),),
((0,),(7,),(2,),(8,),(3,),(7,),(4,),),
((0,),(7,),(2,),(8,),(3,),(8,),(4,),),
((0,),(8,),(2,),(1,),(3,),(1,),(4,),),
((0,),(8,),(2,),(1,),(3,),(5,),(4,),),
((0,),(8,),(2,),(1,),(3,),(6,),(4,),),
((0,),(8,),(2,),(1,),(3,),(7,),(4,),),
((0,),(8,),(2,),(1,),(3,),(8,),(4,),),
((0,),(8,),(2,),(5,),(3,),(1,),(4,),),
((0,),(8,),(2,),(5,),(3,),(5,),(4,),),
((0,),(8,),(2,),(5,),(3,),(6,),(4,),),
((0,),(8,),(2,),(5,),(3,),(7,),(4,),),
((0,),(8,),(2,),(5,),(3,),(8,),(4,),),
((0,),(8,),(2,),(6,),(3,),(1,),(4,),),
((0,),(8,),(2,),(6,),(3,),(5,),(4,),),
((0,),(8,),(2,),(6,),(3,),(6,),(4,),),
((0,),(8,),(2,),(6,),(3,),(7,),(4,),),
((0,),(8,),(2,),(6,),(3,),(8,),(4,),),
((0,),(8,),(2,),(7,),(3,),(1,),(4,),),
((0,),(8,),(2,),(7,),(3,),(5,),(4,),),
((0,),(8,),(2,),(7,),(3,),(6,),(4,),),
((0,),(8,),(2,),(7,),(3,),(7,),(4,),),
((0,),(8,),(2,),(7,),(3,),(8,),(4,),),
((0,),(8,),(2,),(8,),(3,),(1,),(4,),),
((0,),(8,),(2,),(8,),(3,),(5,),(4,),),
((0,),(8,),(2,),(8,),(3,),(6,),(4,),),
((0,),(8,),(2,),(8,),(3,),(7,),(4,),),
((0,),(8,),(2,),(8,),(3,),(8,),(4,),),
((9,),(1,),(2,),(1,),(3,),(1,),(4,),),
((9,),(1,),(2,),(1,),(3,),(5,),(4,),),
((9,),(1,),(2,),(1,),(3,),(6,),(4,),),
((9,),(1,),(2,),(1,),(3,),(7,),(4,),),
((9,),(1,),(2,),(1,),(3,),(8,),(4,),),
((9,),(1,),(2,),(5,),(3,),(1,),(4,),),
((9,),(1,),(2,),(5,),(3,),(5,),(4,),),
((9,),(1,),(2,),(5,),(3,),(6,),(4,),),
((9,),(1,),(2,),(5,),(3,),(7,),(4,),),
((9,),(1,),(2,),(5,),(3,),(8,),(4,),),
((9,),(1,),(2,),(6,),(3,),(1,),(4,),),
((9,),(1,),(2,),(6,),(3,),(5,),(4,),),
((9,),(1,),(2,),(6,),(3,),(6,),(4,),),
((9,),(1,),(2,),(6,),(3,),(7,),(4,),),
((9,),(1,),(2,),(6,),(3,),(8,),(4,),),
((9,),(1,),(2,),(7,),(3,),(1,),(4,),),
((9,),(1,),(2,),(7,),(3,),(5,),(4,),),
((9,),(1,),(2,),(7,),(3,),(6,),(4,),),
((9,),(1,),(2,),(7,),(3,),(7,),(4,),),
((9,),(1,),(2,),(7,),(3,),(8,),(4,),),
((9,),(1,),(2,),(8,),(3,),(1,),(4,),),
((9,),(1,),(2,),(8,),(3,),(5,),(4,),),
((9,),(1,),(2,),(8,),(3,),(6,),(4,),),
((9,),(1,),(2,),(8,),(3,),(7,),(4,),),
((9,),(1,),(2,),(8,),(3,),(8,),(4,),),
((9,),(5,),(2,),(1,),(3,),(1,),(4,),),
((9,),(5,),(2,),(1,),(3,),(5,),(4,),),
((9,),(5,),(2,),(1,),(3,),(6,),(4,),),
((9,),(5,),(2,),(1,),(3,),(7,),(4,),),
((9,),(5,),(2,),(1,),(3,),(8,),(4,),),
((9,),(5,),(2,),(5,),(3,),(1,),(4,),),
((9,),(5,),(2,),(5,),(3,),(5,),(4,),),
((9,),(5,),(2,),(5,),(3,),(6,),(4,),),
((9,),(5,),(2,),(5,),(3,),(7,),(4,),),
((9,),(5,),(2,),(5,),(3,),(8,),(4,),),
((9,),(5,),(2,),(6,),(3,),(1,),(4,),),
((9,),(5,),(2,),(6,),(3,),(5,),(4,),),
((9,),(5,),(2,),(6,),(3,),(6,),(4,),),
((9,),(5,),(2,),(6,),(3,),(7,),(4,),),
((9,),(5,),(2,),(6,),(3,),(8,),(4,),),
((9,),(5,),(2,),(7,),(3,),(1,),(4,),),
((9,),(5,),(2,),(7,),(3,),(5,),(4,),),
((9,),(5,),(2,),(7,),(3,),(6,),(4,),),
((9,),(5,),(2,),(7,),(3,),(7,),(4,),),
((9,),(5,),(2,),(7,),(3,),(8,),(4,),),
((9,),(5,),(2,),(8,),(3,),(1,),(4,),),
((9,),(5,),(2,),(8,),(3,),(5,),(4,),),
((9,),(5,),(2,),(8,),(3,),(6,),(4,),),
((9,),(5,),(2,),(8,),(3,),(7,),(4,),),
((9,),(5,),(2,),(8,),(3,),(8,),(4,),),
((9,),(6,),(2,),(1,),(3,),(1,),(4,),),
((9,),(6,),(2,),(1,),(3,),(5,),(4,),),
((9,),(6,),(2,),(1,),(3,),(6,),(4,),),
((9,),(6,),(2,),(1,),(3,),(7,),(4,),),
((9,),(6,),(2,),(1,),(3,),(8,),(4,),),
((9,),(6,),(2,),(5,),(3,),(1,),(4,),),
((9,),(6,),(2,),(5,),(3,),(5,),(4,),),
((9,),(6,),(2,),(5,),(3,),(6,),(4,),),
((9,),(6,),(2,),(5,),(3,),(7,),(4,),),
((9,),(6,),(2,),(5,),(3,),(8,),(4,),),
((9,),(6,),(2,),(6,),(3,),(1,),(4,),),
((9,),(6,),(2,),(6,),(3,),(5,),(4,),),
((9,),(6,),(2,),(6,),(3,),(6,),(4,),),
((9,),(6,),(2,),(6,),(3,),(7,),(4,),),
((9,),(6,),(2,),(6,),(3,),(8,),(4,),),
((9,),(6,),(2,),(7,),(3,),(1,),(4,),),
((9,),(6,),(2,),(7,),(3,),(5,),(4,),),
((9,),(6,),(2,),(7,),(3,),(6,),(4,),),
((9,),(6,),(2,),(7,),(3,),(7,),(4,),),
((9,),(6,),(2,),(7,),(3,),(8,),(4,),),
((9,),(6,),(2,),(8,),(3,),(1,),(4,),),
((9,),(6,),(2,),(8,),(3,),(5,),(4,),),
((9,),(6,),(2,),(8,),(3,),(6,),(4,),),
((9,),(6,),(2,),(8,),(3,),(7,),(4,),),
((9,),(6,),(2,),(8,),(3,),(8,),(4,),),
((9,),(7,),(2,),(1,),(3,),(1,),(4,),),
((9,),(7,),(2,),(1,),(3,),(5,),(4,),),
((9,),(7,),(2,),(1,),(3,),(6,),(4,),),
((9,),(7,),(2,),(1,),(3,),(7,),(4,),),
((9,),(7,),(2,),(1,),(3,),(8,),(4,),),
((9,),(7,),(2,),(5,),(3,),(1,),(4,),),
((9,),(7,),(2,),(5,),(3,),(5,),(4,),),
((9,),(7,),(2,),(5,),(3,),(6,),(4,),),
((9,),(7,),(2,),(5,),(3,),(7,),(4,),),
((9,),(7,),(2,),(5,),(3,),(8,),(4,),),
((9,),(7,),(2,),(6,),(3,),(1,),(4,),),
((9,),(7,),(2,),(6,),(3,),(5,),(4,),),
((9,),(7,),(2,),(6,),(3,),(6,),(4,),),
((9,),(7,),(2,),(6,),(3,),(7,),(4,),),
((9,),(7,),(2,),(6,),(3,),(8,),(4,),),
((9,),(7,),(2,),(7,),(3,),(1,),(4,),),
((9,),(7,),(2,),(7,),(3,),(5,),(4,),),
((9,),(7,),(2,),(7,),(3,),(6,),(4,),),
((9,),(7,),(2,),(7,),(3,),(7,),(4,),),
((9,),(7,),(2,),(7,),(3,),(8,),(4,),),
((9,),(7,),(2,),(8,),(3,),(1,),(4,),),
((9,),(7,),(2,),(8,),(3,),(5,),(4,),),
((9,),(7,),(2,),(8,),(3,),(6,),(4,),),
((9,),(7,),(2,),(8,),(3,),(7,),(4,),),
((9,),(7,),(2,),(8,),(3,),(8,),(4,),),
((9,),(8,),(2,),(1,),(3,),(1,),(4,),),
((9,),(8,),(2,),(1,),(3,),(5,),(4,),),
((9,),(8,),(2,),(1,),(3,),(6,),(4,),),
((9,),(8,),(2,),(1,),(3,),(7,),(4,),),
((9,),(8,),(2,),(1,),(3,),(8,),(4,),),
((9,),(8,),(2,),(5,),(3,),(1,),(4,),),
((9,),(8,),(2,),(5,),(3,),(5,),(4,),),
((9,),(8,),(2,),(5,),(3,),(6,),(4,),),
((9,),(8,),(2,),(5,),(3,),(7,),(4,),),
((9,),(8,),(2,),(5,),(3,),(8,),(4,),),
((9,),(8,),(2,),(6,),(3,),(1,),(4,),),
((9,),(8,),(2,),(6,),(3,),(5,),(4,),),
((9,),(8,),(2,),(6,),(3,),(6,),(4,),),
((9,),(8,),(2,),(6,),(3,),(7,),(4,),),
((9,),(8,),(2,),(6,),(3,),(8,),(4,),),
((9,),(8,),(2,),(7,),(3,),(1,),(4,),),
((9,),(8,),(2,),(7,),(3,),(5,),(4,),),
((9,),(8,),(2,),(7,),(3,),(6,),(4,),),
((9,),(8,),(2,),(7,),(3,),(7,),(4,),),
((9,),(8,),(2,),(7,),(3,),(8,),(4,),),
((9,),(8,),(2,),(8,),(3,),(1,),(4,),),
((9,),(8,),(2,),(8,),(3,),(5,),(4,),),
((9,),(8,),(2,),(8,),(3,),(6,),(4,),),
((9,),(8,),(2,),(8,),(3,),(7,),(4,),),
((9,),(8,),(2,),(8,),(3,),(8,),(4,),),
((10,),(1,),(2,),(1,),(3,),(1,),(4,),),
((10,),(1,),(2,),(1,),(3,),(5,),(4,),),
((10,),(1,),(2,),(1,),(3,),(6,),(4,),),
((10,),(1,),(2,),(1,),(3,),(7,),(4,),),
((10,),(1,),(2,),(1,),(3,),(8,),(4,),),
((10,),(1,),(2,),(5,),(3,),(1,),(4,),),
((10,),(1,),(2,),(5,),(3,),(5,),(4,),),
((10,),(1,),(2,),(5,),(3,),(6,),(4,),),
((10,),(1,),(2,),(5,),(3,),(7,),(4,),),
((10,),(1,),(2,),(5,),(3,),(8,),(4,),),
((10,),(1,),(2,),(6,),(3,),(1,),(4,),),
((10,),(1,),(2,),(6,),(3,),(5,),(4,),),
((10,),(1,),(2,),(6,),(3,),(6,),(4,),),
((10,),(1,),(2,),(6,),(3,),(7,),(4,),),
((10,),(1,),(2,),(6,),(3,),(8,),(4,),),
((10,),(1,),(2,),(7,),(3,),(1,),(4,),),
((10,),(1,),(2,),(7,),(3,),(5,),(4,),),
((10,),(1,),(2,),(7,),(3,),(6,),(4,),),
((10,),(1,),(2,),(7,),(3,),(7,),(4,),),
((10,),(1,),(2,),(7,),(3,),(8,),(4,),),
((10,),(1,),(2,),(8,),(3,),(1,),(4,),),
((10,),(1,),(2,),(8,),(3,),(5,),(4,),),
((10,),(1,),(2,),(8,),(3,),(6,),(4,),),
((10,),(1,),(2,),(8,),(3,),(7,),(4,),),
((10,),(1,),(2,),(8,),(3,),(8,),(4,),),
((10,),(5,),(2,),(1,),(3,),(1,),(4,),),
((10,),(5,),(2,),(1,),(3,),(5,),(4,),),
((10,),(5,),(2,),(1,),(3,),(6,),(4,),),
((10,),(5,),(2,),(1,),(3,),(7,),(4,),),
((10,),(5,),(2,),(1,),(3,),(8,),(4,),),
((10,),(5,),(2,),(5,),(3,),(1,),(4,),),
((10,),(5,),(2,),(5,),(3,),(5,),(4,),),
((10,),(5,),(2,),(5,),(3,),(6,),(4,),),
((10,),(5,),(2,),(5,),(3,),(7,),(4,),),
((10,),(5,),(2,),(5,),(3,),(8,),(4,),),
((10,),(5,),(2,),(6,),(3,),(1,),(4,),),
((10,),(5,),(2,),(6,),(3,),(5,),(4,),),
((10,),(5,),(2,),(6,),(3,),(6,),(4,),),
((10,),(5,),(2,),(6,),(3,),(7,),(4,),),
((10,),(5,),(2,),(6,),(3,),(8,),(4,),),
((10,),(5,),(2,),(7,),(3,),(1,),(4,),),
((10,),(5,),(2,),(7,),(3,),(5,),(4,),),
((10,),(5,),(2,),(7,),(3,),(6,),(4,),),
((10,),(5,),(2,),(7,),(3,),(7,),(4,),),
((10,),(5,),(2,),(7,),(3,),(8,),(4,),),
((10,),(5,),(2,),(8,),(3,),(1,),(4,),),
((10,),(5,),(2,),(8,),(3,),(5,),(4,),),
((10,),(5,),(2,),(8,),(3,),(6,),(4,),),
((10,),(5,),(2,),(8,),(3,),(7,),(4,),),
((10,),(5,),(2,),(8,),(3,),(8,),(4,),),
((10,),(6,),(2,),(1,),(3,),(1,),(4,),),
((10,),(6,),(2,),(1,),(3,),(5,),(4,),),
((10,),(6,),(2,),(1,),(3,),(6,),(4,),),
((10,),(6,),(2,),(1,),(3,),(7,),(4,),),
((10,),(6,),(2,),(1,),(3,),(8,),(4,),),
((10,),(6,),(2,),(5,),(3,),(1,),(4,),),
((10,),(6,),(2,),(5,),(3,),(5,),(4,),),
((10,),(6,),(2,),(5,),(3,),(6,),(4,),),
((10,),(6,),(2,),(5,),(3,),(7,),(4,),),
((10,),(6,),(2,),(5,),(3,),(8,),(4,),),
((10,),(6,),(2,),(6,),(3,),(1,),(4,),),
((10,),(6,),(2,),(6,),(3,),(5,),(4,),),
((10,),(6,),(2,),(6,),(3,),(6,),(4,),),
((10,),(6,),(2,),(6,),(3,),(7,),(4,),),
((10,),(6,),(2,),(6,),(3,),(8,),(4,),),
((10,),(6,),(2,),(7,),(3,),(1,),(4,),),
((10,),(6,),(2,),(7,),(3,),(5,),(4,),),
((10,),(6,),(2,),(7,),(3,),(6,),(4,),),
((10,),(6,),(2,),(7,),(3,),(7,),(4,),),
((10,),(6,),(2,),(7,),(3,),(8,),(4,),),
((10,),(6,),(2,),(8,),(3,),(1,),(4,),),
((10,),(6,),(2,),(8,),(3,),(5,),(4,),),
((10,),(6,),(2,),(8,),(3,),(6,),(4,),),
((10,),(6,),(2,),(8,),(3,),(7,),(4,),),
((10,),(6,),(2,),(8,),(3,),(8,),(4,),),
((10,),(7,),(2,),(1,),(3,),(1,),(4,),),
((10,),(7,),(2,),(1,),(3,),(5,),(4,),),
((10,),(7,),(2,),(1,),(3,),(6,),(4,),),
((10,),(7,),(2,),(1,),(3,),(7,),(4,),),
((10,),(7,),(2,),(1,),(3,),(8,),(4,),),
((10,),(7,),(2,),(5,),(3,),(1,),(4,),),
((10,),(7,),(2,),(5,),(3,),(5,),(4,),),
((10,),(7,),(2,),(5,),(3,),(6,),(4,),),
((10,),(7,),(2,),(5,),(3,),(7,),(4,),),
((10,),(7,),(2,),(5,),(3,),(8,),(4,),),
((10,),(7,),(2,),(6,),(3,),(1,),(4,),),
((10,),(7,),(2,),(6,),(3,),(5,),(4,),),
((10,),(7,),(2,),(6,),(3,),(6,),(4,),),
((10,),(7,),(2,),(6,),(3,),(7,),(4,),),
((10,),(7,),(2,),(6,),(3,),(8,),(4,),),
((10,),(7,),(2,),(7,),(3,),(1,),(4,),),
((10,),(7,),(2,),(7,),(3,),(5,),(4,),),
((10,),(7,),(2,),(7,),(3,),(6,),(4,),),
((10,),(7,),(2,),(7,),(3,),(7,),(4,),),
((10,),(7,),(2,),(7,),(3,),(8,),(4,),),
((10,),(7,),(2,),(8,),(3,),(1,),(4,),),
((10,),(7,),(2,),(8,),(3,),(5,),(4,),),
((10,),(7,),(2,),(8,),(3,),(6,),(4,),),
((10,),(7,),(2,),(8,),(3,),(7,),(4,),),
((10,),(7,),(2,),(8,),(3,),(8,),(4,),),
((10,),(8,),(2,),(1,),(3,),(1,),(4,),),
((10,),(8,),(2,),(1,),(3,),(5,),(4,),),
((10,),(8,),(2,),(1,),(3,),(6,),(4,),),
((10,),(8,),(2,),(1,),(3,),(7,),(4,),),
((10,),(8,),(2,),(1,),(3,),(8,),(4,),),
((10,),(8,),(2,),(5,),(3,),(1,),(4,),),
((10,),(8,),(2,),(5,),(3,),(5,),(4,),),
((10,),(8,),(2,),(5,),(3,),(6,),(4,),),
((10,),(8,),(2,),(5,),(3,),(7,),(4,),),
((10,),(8,),(2,),(5,),(3,),(8,),(4,),),
((10,),(8,),(2,),(6,),(3,),(1,),(4,),),
((10,),(8,),(2,),(6,),(3,),(5,),(4,),),
((10,),(8,),(2,),(6,),(3,),(6,),(4,),),
((10,),(8,),(2,),(6,),(3,),(7,),(4,),),
((10,),(8,),(2,),(6,),(3,),(8,),(4,),),
((10,),(8,),(2,),(7,),(3,),(1,),(4,),),
((10,),(8,),(2,),(7,),(3,),(5,),(4,),),
((10,),(8,),(2,),(7,),(3,),(6,),(4,),),
((10,),(8,),(2,),(7,),(3,),(7,),(4,),),
((10,),(8,),(2,),(7,),(3,),(8,),(4,),),
((10,),(8,),(2,),(8,),(3,),(1,),(4,),),
((10,),(8,),(2,),(8,),(3,),(5,),(4,),),
((10,),(8,),(2,),(8,),(3,),(6,),(4,),),
((10,),(8,),(2,),(8,),(3,),(7,),(4,),),
((10,),(8,),(2,),(8,),(3,),(8,),(4,),),
((11,),(1,),(2,),(1,),(3,),(1,),(4,),),
((11,),(1,),(2,),(1,),(3,),(5,),(4,),),
((11,),(1,),(2,),(1,),(3,),(6,),(4,),),
((11,),(1,),(2,),(1,),(3,),(7,),(4,),),
((11,),(1,),(2,),(1,),(3,),(8,),(4,),),
((11,),(1,),(2,),(5,),(3,),(1,),(4,),),
((11,),(1,),(2,),(5,),(3,),(5,),(4,),),
((11,),(1,),(2,),(5,),(3,),(6,),(4,),),
((11,),(1,),(2,),(5,),(3,),(7,),(4,),),
((11,),(1,),(2,),(5,),(3,),(8,),(4,),),
((11,),(1,),(2,),(6,),(3,),(1,),(4,),),
((11,),(1,),(2,),(6,),(3,),(5,),(4,),),
((11,),(1,),(2,),(6,),(3,),(6,),(4,),),
((11,),(1,),(2,),(6,),(3,),(7,),(4,),),
((11,),(1,),(2,),(6,),(3,),(8,),(4,),),
((11,),(1,),(2,),(7,),(3,),(1,),(4,),),
((11,),(1,),(2,),(7,),(3,),(5,),(4,),),
((11,),(1,),(2,),(7,),(3,),(6,),(4,),),
((11,),(1,),(2,),(7,),(3,),(7,),(4,),),
((11,),(1,),(2,),(7,),(3,),(8,),(4,),),
((11,),(1,),(2,),(8,),(3,),(1,),(4,),),
((11,),(1,),(2,),(8,),(3,),(5,),(4,),),
((11,),(1,),(2,),(8,),(3,),(6,),(4,),),
((11,),(1,),(2,),(8,),(3,),(7,),(4,),),
((11,),(1,),(2,),(8,),(3,),(8,),(4,),),
((11,),(5,),(2,),(1,),(3,),(1,),(4,),),
((11,),(5,),(2,),(1,),(3,),(5,),(4,),),
((11,),(5,),(2,),(1,),(3,),(6,),(4,),),
((11,),(5,),(2,),(1,),(3,),(7,),(4,),),
((11,),(5,),(2,),(1,),(3,),(8,),(4,),),
((11,),(5,),(2,),(5,),(3,),(1,),(4,),),
((11,),(5,),(2,),(5,),(3,),(5,),(4,),),
((11,),(5,),(2,),(5,),(3,),(6,),(4,),),
((11,),(5,),(2,),(5,),(3,),(7,),(4,),),
((11,),(5,),(2,),(5,),(3,),(8,),(4,),),
((11,),(5,),(2,),(6,),(3,),(1,),(4,),),
((11,),(5,),(2,),(6,),(3,),(5,),(4,),),
((11,),(5,),(2,),(6,),(3,),(6,),(4,),),
((11,),(5,),(2,),(6,),(3,),(7,),(4,),),
((11,),(5,),(2,),(6,),(3,),(8,),(4,),),
((11,),(5,),(2,),(7,),(3,),(1,),(4,),),
((11,),(5,),(2,),(7,),(3,),(5,),(4,),),
((11,),(5,),(2,),(7,),(3,),(6,),(4,),),
((11,),(5,),(2,),(7,),(3,),(7,),(4,),),
((11,),(5,),(2,),(7,),(3,),(8,),(4,),),
((11,),(5,),(2,),(8,),(3,),(1,),(4,),),
((11,),(5,),(2,),(8,),(3,),(5,),(4,),),
((11,),(5,),(2,),(8,),(3,),(6,),(4,),),
((11,),(5,),(2,),(8,),(3,),(7,),(4,),),
((11,),(5,),(2,),(8,),(3,),(8,),(4,),),
((11,),(6,),(2,),(1,),(3,),(1,),(4,),),
((11,),(6,),(2,),(1,),(3,),(5,),(4,),),
((11,),(6,),(2,),(1,),(3,),(6,),(4,),),
((11,),(6,),(2,),(1,),(3,),(7,),(4,),),
((11,),(6,),(2,),(1,),(3,),(8,),(4,),),
((11,),(6,),(2,),(5,),(3,),(1,),(4,),),
((11,),(6,),(2,),(5,),(3,),(5,),(4,),),
((11,),(6,),(2,),(5,),(3,),(6,),(4,),),
((11,),(6,),(2,),(5,),(3,),(7,),(4,),),
((11,),(6,),(2,),(5,),(3,),(8,),(4,),),
((11,),(6,),(2,),(6,),(3,),(1,),(4,),),
((11,),(6,),(2,),(6,),(3,),(5,),(4,),),
((11,),(6,),(2,),(6,),(3,),(6,),(4,),),
((11,),(6,),(2,),(6,),(3,),(7,),(4,),),
((11,),(6,),(2,),(6,),(3,),(8,),(4,),),
((11,),(6,),(2,),(7,),(3,),(1,),(4,),),
((11,),(6,),(2,),(7,),(3,),(5,),(4,),),
((11,),(6,),(2,),(7,),(3,),(6,),(4,),),
((11,),(6,),(2,),(7,),(3,),(7,),(4,),),
((11,),(6,),(2,),(7,),(3,),(8,),(4,),),
((11,),(6,),(2,),(8,),(3,),(1,),(4,),),
((11,),(6,),(2,),(8,),(3,),(5,),(4,),),
((11,),(6,),(2,),(8,),(3,),(6,),(4,),),
((11,),(6,),(2,),(8,),(3,),(7,),(4,),),
((11,),(6,),(2,),(8,),(3,),(8,),(4,),),
((11,),(7,),(2,),(1,),(3,),(1,),(4,),),
((11,),(7,),(2,),(1,),(3,),(5,),(4,),),
((11,),(7,),(2,),(1,),(3,),(6,),(4,),),
((11,),(7,),(2,),(1,),(3,),(7,),(4,),),
((11,),(7,),(2,),(1,),(3,),(8,),(4,),),
((11,),(7,),(2,),(5,),(3,),(1,),(4,),),
((11,),(7,),(2,),(5,),(3,),(5,),(4,),),
((11,),(7,),(2,),(5,),(3,),(6,),(4,),),
((11,),(7,),(2,),(5,),(3,),(7,),(4,),),
((11,),(7,),(2,),(5,),(3,),(8,),(4,),),
((11,),(7,),(2,),(6,),(3,),(1,),(4,),),
((11,),(7,),(2,),(6,),(3,),(5,),(4,),),
((11,),(7,),(2,),(6,),(3,),(6,),(4,),),
((11,),(7,),(2,),(6,),(3,),(7,),(4,),),
((11,),(7,),(2,),(6,),(3,),(8,),(4,),),
((11,),(7,),(2,),(7,),(3,),(1,),(4,),),
((11,),(7,),(2,),(7,),(3,),(5,),(4,),),
((11,),(7,),(2,),(7,),(3,),(6,),(4,),),
((11,),(7,),(2,),(7,),(3,),(7,),(4,),),
((11,),(7,),(2,),(7,),(3,),(8,),(4,),),
((11,),(7,),(2,),(8,),(3,),(1,),(4,),),
((11,),(7,),(2,),(8,),(3,),(5,),(4,),),
((11,),(7,),(2,),(8,),(3,),(6,),(4,),),
((11,),(7,),(2,),(8,),(3,),(7,),(4,),),
((11,),(7,),(2,),(8,),(3,),(8,),(4,),),
((11,),(8,),(2,),(1,),(3,),(1,),(4,),),
((11,),(8,),(2,),(1,),(3,),(5,),(4,),),
((11,),(8,),(2,),(1,),(3,),(6,),(4,),),
((11,),(8,),(2,),(1,),(3,),(7,),(4,),),
((11,),(8,),(2,),(1,),(3,),(8,),(4,),),
((11,),(8,),(2,),(5,),(3,),(1,),(4,),),
((11,),(8,),(2,),(5,),(3,),(5,),(4,),),
((11,),(8,),(2,),(5,),(3,),(6,),(4,),),
((11,),(8,),(2,),(5,),(3,),(7,),(4,),),
((11,),(8,),(2,),(5,),(3,),(8,),(4,),),
((11,),(8,),(2,),(6,),(3,),(1,),(4,),),
((11,),(8,),(2,),(6,),(3,),(5,),(4,),),
((11,),(8,),(2,),(6,),(3,),(6,),(4,),),
((11,),(8,),(2,),(6,),(3,),(7,),(4,),),
((11,),(8,),(2,),(6,),(3,),(8,),(4,),),
((11,),(8,),(2,),(7,),(3,),(1,),(4,),),
((11,),(8,),(2,),(7,),(3,),(5,),(4,),),
((11,),(8,),(2,),(7,),(3,),(6,),(4,),),
((11,),(8,),(2,),(7,),(3,),(7,),(4,),),
((11,),(8,),(2,),(7,),(3,),(8,),(4,),),
((11,),(8,),(2,),(8,),(3,),(1,),(4,),),
((11,),(8,),(2,),(8,),(3,),(5,),(4,),),
((11,),(8,),(2,),(8,),(3,),(6,),(4,),),
((11,),(8,),(2,),(8,),(3,),(7,),(4,),),
((11,),(8,),(2,),(8,),(3,),(8,),(4,),),
((12,),(1,),(2,),(1,),(3,),(1,),(4,),),
((12,),(1,),(2,),(1,),(3,),(5,),(4,),),
((12,),(1,),(2,),(1,),(3,),(6,),(4,),),
((12,),(1,),(2,),(1,),(3,),(7,),(4,),),
((12,),(1,),(2,),(1,),(3,),(8,),(4,),),
((12,),(1,),(2,),(5,),(3,),(1,),(4,),),
((12,),(1,),(2,),(5,),(3,),(5,),(4,),),
((12,),(1,),(2,),(5,),(3,),(6,),(4,),),
((12,),(1,),(2,),(5,),(3,),(7,),(4,),),
((12,),(1,),(2,),(5,),(3,),(8,),(4,),),
((12,),(1,),(2,),(6,),(3,),(1,),(4,),),
((12,),(1,),(2,),(6,),(3,),(5,),(4,),),
((12,),(1,),(2,),(6,),(3,),(6,),(4,),),
((12,),(1,),(2,),(6,),(3,),(7,),(4,),),
((12,),(1,),(2,),(6,),(3,),(8,),(4,),),
((12,),(1,),(2,),(7,),(3,),(1,),(4,),),
((12,),(1,),(2,),(7,),(3,),(5,),(4,),),
((12,),(1,),(2,),(7,),(3,),(6,),(4,),),
((12,),(1,),(2,),(7,),(3,),(7,),(4,),),
((12,),(1,),(2,),(7,),(3,),(8,),(4,),),
((12,),(1,),(2,),(8,),(3,),(1,),(4,),),
((12,),(1,),(2,),(8,),(3,),(5,),(4,),),
((12,),(1,),(2,),(8,),(3,),(6,),(4,),),
((12,),(1,),(2,),(8,),(3,),(7,),(4,),),
((12,),(1,),(2,),(8,),(3,),(8,),(4,),),
((12,),(5,),(2,),(1,),(3,),(1,),(4,),),
((12,),(5,),(2,),(1,),(3,),(5,),(4,),),
((12,),(5,),(2,),(1,),(3,),(6,),(4,),),
((12,),(5,),(2,),(1,),(3,),(7,),(4,),),
((12,),(5,),(2,),(1,),(3,),(8,),(4,),),
((12,),(5,),(2,),(5,),(3,),(1,),(4,),),
((12,),(5,),(2,),(5,),(3,),(5,),(4,),),
((12,),(5,),(2,),(5,),(3,),(6,),(4,),),
((12,),(5,),(2,),(5,),(3,),(7,),(4,),),
((12,),(5,),(2,),(5,),(3,),(8,),(4,),),
((12,),(5,),(2,),(6,),(3,),(1,),(4,),),
((12,),(5,),(2,),(6,),(3,),(5,),(4,),),
((12,),(5,),(2,),(6,),(3,),(6,),(4,),),
((12,),(5,),(2,),(6,),(3,),(7,),(4,),),
((12,),(5,),(2,),(6,),(3,),(8,),(4,),),
((12,),(5,),(2,),(7,),(3,),(1,),(4,),),
((12,),(5,),(2,),(7,),(3,),(5,),(4,),),
((12,),(5,),(2,),(7,),(3,),(6,),(4,),),
((12,),(5,),(2,),(7,),(3,),(7,),(4,),),
((12,),(5,),(2,),(7,),(3,),(8,),(4,),),
((12,),(5,),(2,),(8,),(3,),(1,),(4,),),
((12,),(5,),(2,),(8,),(3,),(5,),(4,),),
((12,),(5,),(2,),(8,),(3,),(6,),(4,),),
((12,),(5,),(2,),(8,),(3,),(7,),(4,),),
((12,),(5,),(2,),(8,),(3,),(8,),(4,),),
((12,),(6,),(2,),(1,),(3,),(1,),(4,),),
((12,),(6,),(2,),(1,),(3,),(5,),(4,),),
((12,),(6,),(2,),(1,),(3,),(6,),(4,),),
((12,),(6,),(2,),(1,),(3,),(7,),(4,),),
((12,),(6,),(2,),(1,),(3,),(8,),(4,),),
((12,),(6,),(2,),(5,),(3,),(1,),(4,),),
((12,),(6,),(2,),(5,),(3,),(5,),(4,),),
((12,),(6,),(2,),(5,),(3,),(6,),(4,),),
((12,),(6,),(2,),(5,),(3,),(7,),(4,),),
((12,),(6,),(2,),(5,),(3,),(8,),(4,),),
((12,),(6,),(2,),(6,),(3,),(1,),(4,),),
((12,),(6,),(2,),(6,),(3,),(5,),(4,),),
((12,),(6,),(2,),(6,),(3,),(6,),(4,),),
((12,),(6,),(2,),(6,),(3,),(7,),(4,),),
((12,),(6,),(2,),(6,),(3,),(8,),(4,),),
((12,),(6,),(2,),(7,),(3,),(1,),(4,),),
((12,),(6,),(2,),(7,),(3,),(5,),(4,),),
((12,),(6,),(2,),(7,),(3,),(6,),(4,),),
((12,),(6,),(2,),(7,),(3,),(7,),(4,),),
((12,),(6,),(2,),(7,),(3,),(8,),(4,),),
((12,),(6,),(2,),(8,),(3,),(1,),(4,),),
((12,),(6,),(2,),(8,),(3,),(5,),(4,),),
((12,),(6,),(2,),(8,),(3,),(6,),(4,),),
((12,),(6,),(2,),(8,),(3,),(7,),(4,),),
((12,),(6,),(2,),(8,),(3,),(8,),(4,),),
((12,),(7,),(2,),(1,),(3,),(1,),(4,),),
((12,),(7,),(2,),(1,),(3,),(5,),(4,),),
((12,),(7,),(2,),(1,),(3,),(6,),(4,),),
((12,),(7,),(2,),(1,),(3,),(7,),(4,),),
((12,),(7,),(2,),(1,),(3,),(8,),(4,),),
((12,),(7,),(2,),(5,),(3,),(1,),(4,),),
((12,),(7,),(2,),(5,),(3,),(5,),(4,),),
((12,),(7,),(2,),(5,),(3,),(6,),(4,),),
((12,),(7,),(2,),(5,),(3,),(7,),(4,),),
((12,),(7,),(2,),(5,),(3,),(8,),(4,),),
((12,),(7,),(2,),(6,),(3,),(1,),(4,),),
((12,),(7,),(2,),(6,),(3,),(5,),(4,),),
((12,),(7,),(2,),(6,),(3,),(6,),(4,),),
((12,),(7,),(2,),(6,),(3,),(7,),(4,),),
((12,),(7,),(2,),(6,),(3,),(8,),(4,),),
((12,),(7,),(2,),(7,),(3,),(1,),(4,),),
((12,),(7,),(2,),(7,),(3,),(5,),(4,),),
((12,),(7,),(2,),(7,),(3,),(6,),(4,),),
((12,),(7,),(2,),(7,),(3,),(7,),(4,),),
((12,),(7,),(2,),(7,),(3,),(8,),(4,),),
((12,),(7,),(2,),(8,),(3,),(1,),(4,),),
((12,),(7,),(2,),(8,),(3,),(5,),(4,),),
((12,),(7,),(2,),(8,),(3,),(6,),(4,),),
((12,),(7,),(2,),(8,),(3,),(7,),(4,),),
((12,),(7,),(2,),(8,),(3,),(8,),(4,),),
((12,),(8,),(2,),(1,),(3,),(1,),(4,),),
((12,),(8,),(2,),(1,),(3,),(5,),(4,),),
((12,),(8,),(2,),(1,),(3,),(6,),(4,),),
((12,),(8,),(2,),(1,),(3,),(7,),(4,),),
((12,),(8,),(2,),(1,),(3,),(8,),(4,),),
((12,),(8,),(2,),(5,),(3,),(1,),(4,),),
((12,),(8,),(2,),(5,),(3,),(5,),(4,),),
((12,),(8,),(2,),(5,),(3,),(6,),(4,),),
((12,),(8,),(2,),(5,),(3,),(7,),(4,),),
((12,),(8,),(2,),(5,),(3,),(8,),(4,),),
((12,),(8,),(2,),(6,),(3,),(1,),(4,),),
((12,),(8,),(2,),(6,),(3,),(5,),(4,),),
((12,),(8,),(2,),(6,),(3,),(6,),(4,),),
((12,),(8,),(2,),(6,),(3,),(7,),(4,),),
((12,),(8,),(2,),(6,),(3,),(8,),(4,),),
((12,),(8,),(2,),(7,),(3,),(1,),(4,),),
((12,),(8,),(2,),(7,),(3,),(5,),(4,),),
((12,),(8,),(2,),(7,),(3,),(6,),(4,),),
((12,),(8,),(2,),(7,),(3,),(7,),(4,),),
((12,),(8,),(2,),(7,),(3,),(8,),(4,),),
((12,),(8,),(2,),(8,),(3,),(1,),(4,),),
((12,),(8,),(2,),(8,),(3,),(5,),(4,),),
((12,),(8,),(2,),(8,),(3,),(6,),(4,),),
((12,),(8,),(2,),(8,),(3,),(7,),(4,),),
((12,),(8,),(2,),(8,),(3,),(8,),(4,),)
	]

